svn commit: r295201 - head/sys/arm/xscale/i8134x

2016-02-03 Thread Michal Meloun
Author: mmel
Date: Wed Feb  3 10:39:29 2016
New Revision: 295201
URL: https://svnweb.freebsd.org/changeset/base/295201

Log:
  ARM: Remove C++ comments erroneously committed  in r295200.

Modified:
  head/sys/arm/xscale/i8134x/i80321reg.h

Modified: head/sys/arm/xscale/i8134x/i80321reg.h
==
--- head/sys/arm/xscale/i8134x/i80321reg.h  Wed Feb  3 09:15:44 2016
(r295200)
+++ head/sys/arm/xscale/i8134x/i80321reg.h  Wed Feb  3 10:39:29 2016
(r295201)
@@ -331,12 +331,12 @@
 #defineICU_INT_bit26   26
 
 /* CPU_XSCALE_80321 */
-//#define  ICU_INT_SSP 25  /* SSP serial port */
+#defineICU_INT_SSP 25  /* SSP serial port */
 
 #defineICU_INT_MUE 24  /* msg unit error */
 
 /* CPU_XSCALE_80321 */
-//#define  ICU_INT_AAUE23  /* AAU error */
+#defineICU_INT_AAUE23  /* AAU error */
 
 #defineICU_INT_bit22   22
 #defineICU_INT_DMA1E   21  /* DMA Ch 1 error */
@@ -355,8 +355,8 @@
 #defineICU_INT_CPPM8   /* core processor PMU */
 
 /* CPU_XSCALE_80321 */
-//#define  ICU_INT_AAU_EOC 7   /* AAU end-of-chain */
-//#define  ICU_INT_AAU_EOT 6   /* AAU end-of-transfer */
+#defineICU_INT_AAU_EOC 7   /* AAU end-of-chain */
+#defineICU_INT_AAU_EOT 6   /* AAU end-of-transfer */
 
 #defineICU_INT_bit55
 #defineICU_INT_bit44
@@ -366,11 +366,11 @@
 #defineICU_INT_DMA0_EOT0   /* DMA0 end-of-transfer */
 
 /* CPU_XSCALE_80321 */
-//#define  ICU_INT_HWMASK  (0x & \
-// ~((1 << ICU_INT_bit26) | \
-//   (1 << ICU_INT_bit22) | \
-//   (1 << ICU_INT_bit5)  | \
-//   (1 << ICU_INT_bit4)))
+#defineICU_INT_HWMASK  (0x & \
+   ~((1 << ICU_INT_bit26) | \
+ (1 << ICU_INT_bit22) | \
+ (1 << ICU_INT_bit5)  | \
+ (1 << ICU_INT_bit4)))
 
 /*
  * Peripheral Bus Interface Unit
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


Re: svn commit: r295168 - in head/sys/arm: arm include

2016-02-03 Thread Wojciech Macek
Is it necessary to add acle-compat.h to the includes? If so, I suggest
putting it under ifndef __aarch64__ , to fix the ARM64 build.

Regards,
Wojtek

2016-02-02 22:17 GMT+01:00 Svatopluk Kraus :

> Author: skra
> Date: Tue Feb  2 21:17:25 2016
> New Revision: 295168
> URL: https://svnweb.freebsd.org/changeset/base/295168
>
> Log:
>   Use pmap_preboot_map_attr() directly in arm_devmap_bootstrap()
>   instead of hiding behind pmap_map_chunk(). It's not longer needed
>   after old pmap-v6 code was removed.
>
>   For compatibility with __ARM_ARCH < 6, define PTE_DEVICE in devmap.c
>   file. Certainly, it would be nice if VM_MEMATTR_DEVICE could be used
>   even for __ARM_ARCH < 6.
>
> Modified:
>   head/sys/arm/arm/devmap.c
>   head/sys/arm/include/pmap-v6.h
>
> Modified: head/sys/arm/arm/devmap.c
>
> ==
> --- head/sys/arm/arm/devmap.c   Tue Feb  2 21:11:23 2016(r295167)
> +++ head/sys/arm/arm/devmap.c   Tue Feb  2 21:17:25 2016(r295168)
> @@ -40,6 +40,7 @@ __FBSDID("$FreeBSD$");
>  #include 
>  #include 
>  #include 
> +#include 
>  #include 
>  #include 
>  #include 
> @@ -52,6 +53,9 @@ static boolean_t devmap_bootstrap_done =
>  #definePTE_DEVICE  VM_MEMATTR_DEVICE
>  #elif defined(__arm__)
>  #defineMAX_VADDR   ARM_VECTORS_HIGH
> +#if __ARM_ARCH >= 6
> +#definePTE_DEVICE  VM_MEMATTR_DEVICE
> +#endif
>  #endif
>
>  /*
> @@ -204,8 +208,13 @@ arm_devmap_bootstrap(vm_offset_t l1pt, c
>
> for (pd = devmap_table; pd->pd_size != 0; ++pd) {
>  #if defined(__arm__)
> +#if __ARM_ARCH >= 6
> +   pmap_preboot_map_attr(pd->pd_pa, pd->pd_va, pd->pd_size,
> +   pd->pd_prot, pd->pd_cache);
> +#else
> pmap_map_chunk(l1pt, pd->pd_va, pd->pd_pa, pd->pd_size,
> -   pd->pd_prot,pd->pd_cache);
> +   pd->pd_prot, pd->pd_cache);
> +#endif
>  #elif defined(__aarch64__)
> pmap_kenter_device(pd->pd_va, pd->pd_size, pd->pd_pa);
>  #endif
>
> Modified: head/sys/arm/include/pmap-v6.h
>
> ==
> --- head/sys/arm/include/pmap-v6.h  Tue Feb  2 21:11:23 2016
> (r295167)
> +++ head/sys/arm/include/pmap-v6.h  Tue Feb  2 21:17:25 2016
> (r295168)
> @@ -218,12 +218,6 @@ vm_offset_t pmap_preboot_reserve_pages(u
>  vm_offset_t pmap_preboot_get_vpages(u_int );
>  void pmap_preboot_map_attr(vm_paddr_t, vm_offset_t, vm_size_t, vm_prot_t,
>  vm_memattr_t);
> -static __inline void
> -pmap_map_chunk(vm_offset_t l1pt, vm_offset_t va, vm_offset_t pa,
> -vm_size_t size, int prot, int cache)
> -{
> -   pmap_preboot_map_attr(pa, va, size, prot, cache);
> -}
>
>  #endif /* _KERNEL */
>
> @@ -256,29 +250,6 @@ pmap_map_chunk(vm_offset_t l1pt, vm_offs
>   */
>  void vector_page_setprot(int);
>
> -/*
> - * sys/arm/arm/bus_space_generic.c (just comment)
> - * sys/arm/arm/devmap.c
> - * sys/arm/arm/pmap.c (just comment)
> - * sys/arm/at91/at91_machdep.c
> - * sys/arm/cavium/cns11xx/econa_machdep.c
> - * sys/arm/freescale/imx/imx6_machdep.c (just comment)
> - * sys/arm/mv/orion/db88f5xxx.c
> - * sys/arm/mv/mv_localbus.c
> - * sys/arm/mv/mv_machdep.c
> - * sys/arm/mv/mv_pci.c
> - * sys/arm/s3c2xx0/s3c24x0_machdep.c
> - * sys/arm/versatile/versatile_machdep.c
> - * sys/arm/xscale/ixp425/avila_machdep.c
> - * sys/arm/xscale/i8134x/crb_machdep.c
> - * sys/arm/xscale/i80321/ep80219_machdep.c
> - * sys/arm/xscale/i80321/iq31244_machdep.c
> - * sys/arm/xscale/pxa/pxa_machdep.c
> - */
> -#define PTE_DEVICE PTE2_ATTR_DEVICE
> -
> -
> -
>  #endif /* _KERNEL */
>  //
> -
>
>
>
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


svn commit: r295202 - head/contrib/bsnmp/snmp_mibII

2016-02-03 Thread Bjoern A. Zeeb
Author: bz
Date: Wed Feb  3 11:03:44 2016
New Revision: 295202
URL: https://svnweb.freebsd.org/changeset/base/295202

Log:
  Try to fix a bug introduced in r228623.  We started to copy the ifa_msghdr
  as otherwise platforms with strict alignment would break.  It's unclear
  to me if there's also a problem with access to the address list following
  the structure.  However we never copied the address list after the structure
  and thus are pointing at random memory.  For now just use a pointer to the
  original memory for accessing the address list making it at least work on
  platforms with weak memory access.
  
  PR:   195445
  Reported by:  wolfgang lyxys.ka.sub.org
  Tested by:wolfgang lyxys.ka.sub.org (x86)
  MFC after:3 days

Modified:
  head/contrib/bsnmp/snmp_mibII/mibII.c

Modified: head/contrib/bsnmp/snmp_mibII/mibII.c
==
--- head/contrib/bsnmp/snmp_mibII/mibII.c   Wed Feb  3 10:39:29 2016
(r295201)
+++ head/contrib/bsnmp/snmp_mibII/mibII.c   Wed Feb  3 11:03:44 2016
(r295202)
@@ -982,7 +982,7 @@ handle_rtmsg(struct rt_msghdr *rtm)
 {
struct sockaddr *addrs[RTAX_MAX];
struct if_msghdr *ifm;
-   struct ifa_msghdr ifam;
+   struct ifa_msghdr ifam, *ifamp;
struct ifma_msghdr *ifmam;
 #ifdef RTM_IFANNOUNCE
struct if_announcemsghdr *ifan;
@@ -1002,8 +1002,9 @@ handle_rtmsg(struct rt_msghdr *rtm)
switch (rtm->rtm_type) {
 
  case RTM_NEWADDR:
-   memcpy(, rtm, sizeof(ifam));
-   mib_extract_addrs(ifam.ifam_addrs, (u_char *)( + 1), 
addrs);
+   ifamp = (struct ifa_msghdr *)rtm;
+   memcpy(, ifamp, sizeof(ifam));
+   mib_extract_addrs(ifam.ifam_addrs, (u_char *)(ifamp + 1), 
addrs);
if (addrs[RTAX_IFA] == NULL || addrs[RTAX_NETMASK] == NULL)
break;
 
@@ -1029,8 +1030,9 @@ handle_rtmsg(struct rt_msghdr *rtm)
break;
 
  case RTM_DELADDR:
-   memcpy(, rtm, sizeof(ifam));
-   mib_extract_addrs(ifam.ifam_addrs, (u_char *)( + 1), 
addrs);
+   ifamp = (struct ifa_msghdr *)rtm;
+   memcpy(, ifamp, sizeof(ifam));
+   mib_extract_addrs(ifam.ifam_addrs, (u_char *)(ifamp + 1), 
addrs);
if (addrs[RTAX_IFA] == NULL)
break;
 
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


Re: svn commit: r295168 - in head/sys/arm: arm include

2016-02-03 Thread Svatopluk Kraus
Well, I was told that acle-compat.h is needed when __ARM_ARCH is used
as some older or newer, not sure now, gcc does not defines it for us.
I think that it came to me from andrew@.

BTW, the aarch64 kernel build was fixed in r295198 by mmel@. Thanks.

Svata

On Wed, Feb 3, 2016 at 9:01 AM, Wojciech Macek  wrote:
> Is it necessary to add acle-compat.h to the includes? If so, I suggest
> putting it under ifndef __aarch64__ , to fix the ARM64 build.
>
> Regards,
> Wojtek
>
> 2016-02-02 22:17 GMT+01:00 Svatopluk Kraus :
>>
>> Author: skra
>> Date: Tue Feb  2 21:17:25 2016
>> New Revision: 295168
>> URL: https://svnweb.freebsd.org/changeset/base/295168
>>
>> Log:
>>   Use pmap_preboot_map_attr() directly in arm_devmap_bootstrap()
>>   instead of hiding behind pmap_map_chunk(). It's not longer needed
>>   after old pmap-v6 code was removed.
>>
>>   For compatibility with __ARM_ARCH < 6, define PTE_DEVICE in devmap.c
>>   file. Certainly, it would be nice if VM_MEMATTR_DEVICE could be used
>>   even for __ARM_ARCH < 6.
>>
>> Modified:
>>   head/sys/arm/arm/devmap.c
>>   head/sys/arm/include/pmap-v6.h
>>
>> Modified: head/sys/arm/arm/devmap.c
>>
>> ==
>> --- head/sys/arm/arm/devmap.c   Tue Feb  2 21:11:23 2016(r295167)
>> +++ head/sys/arm/arm/devmap.c   Tue Feb  2 21:17:25 2016(r295168)
>> @@ -40,6 +40,7 @@ __FBSDID("$FreeBSD$");
>>  #include 
>>  #include 
>>  #include 
>> +#include 
>>  #include 
>>  #include 
>>  #include 
>> @@ -52,6 +53,9 @@ static boolean_t devmap_bootstrap_done =
>>  #definePTE_DEVICE  VM_MEMATTR_DEVICE
>>  #elif defined(__arm__)
>>  #defineMAX_VADDR   ARM_VECTORS_HIGH
>> +#if __ARM_ARCH >= 6
>> +#definePTE_DEVICE  VM_MEMATTR_DEVICE
>> +#endif
>>  #endif
>>
>>  /*
>> @@ -204,8 +208,13 @@ arm_devmap_bootstrap(vm_offset_t l1pt, c
>>
>> for (pd = devmap_table; pd->pd_size != 0; ++pd) {
>>  #if defined(__arm__)
>> +#if __ARM_ARCH >= 6
>> +   pmap_preboot_map_attr(pd->pd_pa, pd->pd_va, pd->pd_size,
>> +   pd->pd_prot, pd->pd_cache);
>> +#else
>> pmap_map_chunk(l1pt, pd->pd_va, pd->pd_pa, pd->pd_size,
>> -   pd->pd_prot,pd->pd_cache);
>> +   pd->pd_prot, pd->pd_cache);
>> +#endif
>>  #elif defined(__aarch64__)
>> pmap_kenter_device(pd->pd_va, pd->pd_size, pd->pd_pa);
>>  #endif
>>
>> Modified: head/sys/arm/include/pmap-v6.h
>>
>> ==
>> --- head/sys/arm/include/pmap-v6.h  Tue Feb  2 21:11:23 2016
>> (r295167)
>> +++ head/sys/arm/include/pmap-v6.h  Tue Feb  2 21:17:25 2016
>> (r295168)
>> @@ -218,12 +218,6 @@ vm_offset_t pmap_preboot_reserve_pages(u
>>  vm_offset_t pmap_preboot_get_vpages(u_int );
>>  void pmap_preboot_map_attr(vm_paddr_t, vm_offset_t, vm_size_t, vm_prot_t,
>>  vm_memattr_t);
>> -static __inline void
>> -pmap_map_chunk(vm_offset_t l1pt, vm_offset_t va, vm_offset_t pa,
>> -vm_size_t size, int prot, int cache)
>> -{
>> -   pmap_preboot_map_attr(pa, va, size, prot, cache);
>> -}
>>
>>  #endif /* _KERNEL */
>>
>> @@ -256,29 +250,6 @@ pmap_map_chunk(vm_offset_t l1pt, vm_offs
>>   */
>>  void vector_page_setprot(int);
>>
>> -/*
>> - * sys/arm/arm/bus_space_generic.c (just comment)
>> - * sys/arm/arm/devmap.c
>> - * sys/arm/arm/pmap.c (just comment)
>> - * sys/arm/at91/at91_machdep.c
>> - * sys/arm/cavium/cns11xx/econa_machdep.c
>> - * sys/arm/freescale/imx/imx6_machdep.c (just comment)
>> - * sys/arm/mv/orion/db88f5xxx.c
>> - * sys/arm/mv/mv_localbus.c
>> - * sys/arm/mv/mv_machdep.c
>> - * sys/arm/mv/mv_pci.c
>> - * sys/arm/s3c2xx0/s3c24x0_machdep.c
>> - * sys/arm/versatile/versatile_machdep.c
>> - * sys/arm/xscale/ixp425/avila_machdep.c
>> - * sys/arm/xscale/i8134x/crb_machdep.c
>> - * sys/arm/xscale/i80321/ep80219_machdep.c
>> - * sys/arm/xscale/i80321/iq31244_machdep.c
>> - * sys/arm/xscale/pxa/pxa_machdep.c
>> - */
>> -#define PTE_DEVICE PTE2_ATTR_DEVICE
>> -
>> -
>> -
>>  #endif /* _KERNEL */
>>  //
>> -
>>
>>
>
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


svn commit: r295198 - head/sys/arm/arm

2016-02-03 Thread Michal Meloun
Author: mmel
Date: Wed Feb  3 08:12:21 2016
New Revision: 295198
URL: https://svnweb.freebsd.org/changeset/base/295198

Log:
  ARM: acle-compat.h is arm specific header, don't include it for aarch64. This
  fixes aarch64 buildkernel.

Modified:
  head/sys/arm/arm/devmap.c

Modified: head/sys/arm/arm/devmap.c
==
--- head/sys/arm/arm/devmap.c   Wed Feb  3 04:02:50 2016(r295197)
+++ head/sys/arm/arm/devmap.c   Wed Feb  3 08:12:21 2016(r295198)
@@ -40,7 +40,9 @@ __FBSDID("$FreeBSD$");
 #include 
 #include 
 #include 
+#ifdef __arm__
 #include 
+#endif
 #include 
 #include 
 #include 
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


svn commit: r295200 - in head/sys: arm/arm arm/conf arm/include arm/xscale/i80321 arm/xscale/i8134x conf

2016-02-03 Thread Michal Meloun
Author: mmel
Date: Wed Feb  3 09:15:44 2016
New Revision: 295200
URL: https://svnweb.freebsd.org/changeset/base/295200

Log:
  ARM: Remove support for xscale i80219 and i80321 CPUs. We haven't single
  supported config/board with these CPUs.

Deleted:
  head/sys/arm/xscale/i80321/
Modified:
  head/sys/arm/arm/cpufunc.c
  head/sys/arm/arm/elf_trampoline.c
  head/sys/arm/conf/NOTES
  head/sys/arm/include/cpuconf.h
  head/sys/arm/include/cpufunc.h
  head/sys/arm/xscale/i8134x/i80321reg.h
  head/sys/conf/files.arm
  head/sys/conf/options.arm

Modified: head/sys/arm/arm/cpufunc.c
==
--- head/sys/arm/arm/cpufunc.c  Wed Feb  3 08:59:12 2016(r295199)
+++ head/sys/arm/arm/cpufunc.c  Wed Feb  3 09:15:44 2016(r295200)
@@ -60,18 +60,7 @@ __FBSDID("$FreeBSD$");
 #include 
 #include 
 
-#if defined(CPU_XSCALE_80321) || defined(CPU_XSCALE_80219)
-#include 
-#include 
-#endif
-
-/*
- * Some definitions in i81342reg.h clash with i80321reg.h.
- * This only happens for the LINT kernel. As it happens,
- * we don't need anything from i81342reg.h that we already
- * got from somewhere else during a LINT compile.
- */
-#if defined(CPU_XSCALE_81342) && !defined(COMPILING_LINT)
+#if defined(CPU_XSCALE_81342)
 #include 
 #endif
 
@@ -306,9 +295,7 @@ struct cpu_functions pj4bv7_cpufuncs = {
 };
 #endif /* CPU_MV_PJ4B */
 
-#if defined(CPU_XSCALE_80321) || \
-  defined(CPU_XSCALE_PXA2X0) || defined(CPU_XSCALE_IXP425) || \
-  defined(CPU_XSCALE_80219)
+#if defined(CPU_XSCALE_PXA2X0) || defined(CPU_XSCALE_IXP425)
 
 struct cpu_functions xscale_cpufuncs = {
/* CPU functions */
@@ -359,8 +346,7 @@ struct cpu_functions xscale_cpufuncs = {
xscale_setup/* cpu setup*/
 };
 #endif
-/* CPU_XSCALE_80321 || CPU_XSCALE_PXA2X0 || CPU_XSCALE_IXP425
-   CPU_XSCALE_80219 */
+/* CPU_XSCALE_PXA2X0 || CPU_XSCALE_IXP425 */
 
 #ifdef CPU_XSCALE_81342
 struct cpu_functions xscalec3_cpufuncs = {
@@ -588,10 +574,10 @@ u_int cpu_reset_needs_v4_MMU_disable; /*
 
 #if defined(CPU_ARM9) ||   \
   defined (CPU_ARM9E) ||   \
-  defined(CPU_ARM1176) || defined(CPU_XSCALE_80321) || \
+  defined(CPU_ARM1176) ||  \
   defined(CPU_XSCALE_PXA2X0) || defined(CPU_XSCALE_IXP425) ||  \
   defined(CPU_FA526) || defined(CPU_MV_PJ4B) ||\
-  defined(CPU_XSCALE_80219) || defined(CPU_XSCALE_81342) || \
+  defined(CPU_XSCALE_81342) || \
   defined(CPU_CORTEXA) || defined(CPU_KRAIT)
 
 /* Global cache line sizes, use 32 as default */
@@ -829,18 +815,6 @@ set_cpufuncs()
}
 #endif /* CPU_FA526 */
 
-#if defined(CPU_XSCALE_80321) || defined(CPU_XSCALE_80219)
-   if (cputype == CPU_ID_80321_400 || cputype == CPU_ID_80321_600 ||
-   cputype == CPU_ID_80321_400_B0 || cputype == CPU_ID_80321_600_B0 ||
-   cputype == CPU_ID_80219_400 || cputype == CPU_ID_80219_600) {
-   cpufuncs = xscale_cpufuncs;
-   cpu_reset_needs_v4_MMU_disable = 1; /* XScale needs it */
-   get_cachetype_cp15();
-   pmap_pte_init_xscale();
-   goto out;
-   }
-#endif /* CPU_XSCALE_80321 */
-
 #if defined(CPU_XSCALE_81342)
if (cputype == CPU_ID_81342) {
cpufuncs = xscalec3_cpufuncs;
@@ -1207,9 +1181,8 @@ fa526_setup(void)
 }
 #endif /* CPU_FA526 */
 
-#if defined(CPU_XSCALE_80321) || \
-  defined(CPU_XSCALE_PXA2X0) || defined(CPU_XSCALE_IXP425) || \
-  defined(CPU_XSCALE_80219) || defined(CPU_XSCALE_81342)
+#if defined(CPU_XSCALE_PXA2X0) || defined(CPU_XSCALE_IXP425) || \
+  defined(CPU_XSCALE_81342)
 void
 xscale_setup(void)
 {
@@ -1276,5 +1249,4 @@ xscale_setup(void)
__asm __volatile("mcr p15, 0, %0, c1, c0, 1"
: : "r" (auxctl));
 }
-#endif /* CPU_XSCALE_80321 || CPU_XSCALE_PXA2X0 || CPU_XSCALE_IXP425
-  CPU_XSCALE_80219 */
+#endif /* CPU_XSCALE_PXA2X0 || CPU_XSCALE_IXP425 */

Modified: head/sys/arm/arm/elf_trampoline.c
==
--- head/sys/arm/arm/elf_trampoline.c   Wed Feb  3 08:59:12 2016
(r295199)
+++ head/sys/arm/arm/elf_trampoline.c   Wed Feb  3 09:15:44 2016
(r295200)
@@ -67,9 +67,7 @@ extern void fa526_idcache_wbinv_all(void
 extern void armv5_ec_idcache_wbinv_all(void);
 #elif defined(CPU_ARM1176)
 #define cpu_idcache_wbinv_all  armv6_idcache_wbinv_all
-#elif defined(CPU_XSCALE_80321) || \
-  defined(CPU_XSCALE_PXA2X0) || defined(CPU_XSCALE_IXP425) ||  \
-  defined(CPU_XSCALE_80219)
+#elif defined(CPU_XSCALE_PXA2X0) || defined(CPU_XSCALE_IXP425)
 #define cpu_idcache_wbinv_all  xscale_cache_purgeID
 extern void xscale_cache_purgeID(void);
 #elif defined(CPU_XSCALE_81342)

Modified: head/sys/arm/conf/NOTES
==
--- head/sys/arm/conf/NOTES Wed Feb  3 08:59:12 2016(r295199)
+++ 

svn commit: r295199 - head/sys/arm/xscale/i8134x

2016-02-03 Thread Michal Meloun
Author: mmel
Date: Wed Feb  3 08:59:12 2016
New Revision: 295199
URL: https://svnweb.freebsd.org/changeset/base/295199

Log:
  ARM: The arm/xscale/i80321 directory is now orphaned, but two drivers
  are shared with i8134x. In preparation for removal of i80321, copy these
  drivers to i8134x.

Added:
  head/sys/arm/xscale/i8134x/i80321_timer.c
 - copied, changed from r295197, head/sys/arm/xscale/i80321/i80321_timer.c
  head/sys/arm/xscale/i8134x/i80321_wdog.c
 - copied, changed from r295197, head/sys/arm/xscale/i80321/i80321_wdog.c
  head/sys/arm/xscale/i8134x/i80321reg.h
 - copied unchanged from r295197, head/sys/arm/xscale/i80321/i80321reg.h
  head/sys/arm/xscale/i8134x/i80321var.h
 - copied unchanged from r295197, head/sys/arm/xscale/i80321/i80321var.h
Modified:
  head/sys/arm/xscale/i8134x/crb_machdep.c
  head/sys/arm/xscale/i8134x/files.i81342

Modified: head/sys/arm/xscale/i8134x/crb_machdep.c
==
--- head/sys/arm/xscale/i8134x/crb_machdep.cWed Feb  3 08:12:21 2016
(r295198)
+++ head/sys/arm/xscale/i8134x/crb_machdep.cWed Feb  3 08:59:12 2016
(r295199)
@@ -92,7 +92,7 @@ __FBSDID("$FreeBSD$");
 #include 
 
 
-#include  /* For i80321_calibrate_delay() */
+#include  /* For i80321_calibrate_delay() */
 
 #include 
 #include 

Modified: head/sys/arm/xscale/i8134x/files.i81342
==
--- head/sys/arm/xscale/i8134x/files.i81342 Wed Feb  3 08:12:21 2016
(r295198)
+++ head/sys/arm/xscale/i8134x/files.i81342 Wed Feb  3 08:59:12 2016
(r295199)
@@ -1,7 +1,7 @@
 # $FreeBSD$
 arm/arm/bus_space_base.c   standard
-arm/xscale/i80321/i80321_timer.c   standard
-arm/xscale/i80321/i80321_wdog.coptionaliopwdog
+arm/xscale/i8134x/i80321_timer.c   standard
+arm/xscale/i8134x/i80321_wdog.coptionaliopwdog
 arm/xscale/i8134x/i81342.c standard
 arm/xscale/i8134x/i81342_mcu.c standard
 arm/xscale/i8134x/i81342_pci.c optionalpci

Copied and modified: head/sys/arm/xscale/i8134x/i80321_timer.c (from r295197, 
head/sys/arm/xscale/i80321/i80321_timer.c)
==
--- head/sys/arm/xscale/i80321/i80321_timer.c   Wed Feb  3 04:02:50 2016
(r295197, copy source)
+++ head/sys/arm/xscale/i8134x/i80321_timer.c   Wed Feb  3 08:59:12 2016
(r295199)
@@ -59,8 +59,8 @@ __FBSDID("$FreeBSD$");
 #include 
 #include 
 #include 
-#include 
-#include 
+#include 
+#include 
 
 #ifdef CPU_XSCALE_81342
 #define ICU_INT_TIMER0 (8) /* XXX: Can't include i81342reg.h because

Copied and modified: head/sys/arm/xscale/i8134x/i80321_wdog.c (from r295197, 
head/sys/arm/xscale/i80321/i80321_wdog.c)
==
--- head/sys/arm/xscale/i80321/i80321_wdog.cWed Feb  3 04:02:50 2016
(r295197, copy source)
+++ head/sys/arm/xscale/i8134x/i80321_wdog.cWed Feb  3 08:59:12 2016
(r295199)
@@ -54,8 +54,8 @@ __FBSDID("$FreeBSD$");
 #include 
 #include 
 
-#include 
-#include 
+#include 
+#include 
 
 
 struct iopwdog_softc {

Copied: head/sys/arm/xscale/i8134x/i80321reg.h (from r295197, 
head/sys/arm/xscale/i80321/i80321reg.h)
==
--- /dev/null   00:00:00 1970   (empty, because file is newly added)
+++ head/sys/arm/xscale/i8134x/i80321reg.h  Wed Feb  3 08:59:12 2016
(r295199, copy of r295197, head/sys/arm/xscale/i80321/i80321reg.h)
@@ -0,0 +1,547 @@
+/* $NetBSD: i80321reg.h,v 1.14 2003/12/19 10:08:11 gavan Exp $ */
+
+/*-
+ * Copyright (c) 2002 Wasabi Systems, Inc.
+ * All rights reserved.
+ *
+ * Written by Jason R. Thorpe for Wasabi Systems, Inc.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *notice, this list of conditions and the following disclaimer in the
+ *documentation and/or other materials provided with the distribution.
+ * 3. All advertising materials mentioning features or use of this software
+ *must display the following acknowledgement:
+ * This product includes software developed for the NetBSD Project by
+ * Wasabi Systems, Inc.
+ * 4. The name of Wasabi Systems, Inc. may not be used to endorse
+ *or promote products derived from this software without specific prior
+ *written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY WASABI SYSTEMS, INC. ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
+ * TO, THE 

svn commit: r295204 - head/bin/csh

2016-02-03 Thread Hajimu UMEMOTO
Author: ume
Date: Wed Feb  3 11:44:43 2016
New Revision: 295204
URL: https://svnweb.freebsd.org/changeset/base/295204

Log:
  The charset of NLS catalogs were converted to UTF-8
  since r231990.

Modified:
  head/bin/csh/Makefile

Modified: head/bin/csh/Makefile
==
--- head/bin/csh/Makefile   Wed Feb  3 11:41:55 2016(r295203)
+++ head/bin/csh/Makefile   Wed Feb  3 11:44:43 2016(r295204)
@@ -51,41 +51,40 @@ FILESDIR= ${SHAREDIR}/examples/tcsh
 FILES= complete.tcsh csh-mode.el
 .endif
 
-CATALOGS=  et:et_EE.ISO8859-15 \
-   finnish:fi_FI.ISO8859-1 \
-   french:fr_FR.ISO8859-1 \
-   german:de_DE.ISO8859-1 \
-   greek:el_GR.ISO8859-7 \
-   italian:it_IT.ISO8859-1 \
-   ja:ja_JP.eucJP \
-   russian:ru_RU.KOI8-R \
-   spanish:es_ES.ISO8859-1 \
-   ukrainian:uk_UA.KOI8-U
-
-NLSLINKS_fi_FI.ISO8859-1= fi_FI.ISO8859-15
-NLSLINKS_fr_FR.ISO8859-1= fr_BE.ISO8859-1 fr_BE.ISO8859-15 \
-   fr_CA.ISO8859-1 fr_CA.ISO8859-15 fr_CH.ISO8859-1 \
-   fr_CH.ISO8859-15 fr_FR.ISO8859-15
-NLSLINKS_de_DE.ISO8859-1= de_AT.ISO8859-1 de_AT.ISO8859-15 de_CH.ISO8859-1 \
-   de_CH.ISO8859-15 de_DE.ISO8859-15
-NLSLINKS_it_IT.ISO8859-1= it_CH.ISO8859-1 it_CH.ISO8859-15 it_IT.ISO8859-15
-NLSLINKS_es_ES.ISO8859-1= es_ES.ISO8859-15
+CATALOGS=  et:et_EE.UTF-8 \
+   finnish:fi_FI.UTF-8 \
+   french:fr_FR.UTF-8 \
+   german:de_DE.UTF-8 \
+   greek:el_GR.UTF-8 \
+   italian:it_IT.UTF-8 \
+   ja:ja_JP.UTF-8 \
+   russian:ru_RU.UTF-8 \
+   spanish:es_ES.UTF-8 \
+   ukrainian:uk_UA.UTF-8
+
+NLSLINKS_de_DE.UTF-8 = de_AT.UTF-8 de_CH.UTF-8 de_DE.UTF-8
+NLSLINKS_fr_FR.UTF-8 = fr_BE.UTF-8 fr_CA.UTF-8 fr_CH.UTF-8
+NLSLINKS_it_IT.UTF-8 = it_CH.UTF-8
 
 .if ${MK_NLS_CATALOGS} == "no" || defined(RESCUE)
 CFLAGS+= -DNO_NLS_CATALOGS
 .else
 CFLAGS+= -DHAVE_ICONV
 .if ${MK_ICONV} != "no"
-NLSLINKS_de_DE.ISO8859-1 += de_AT.UTF-8 de_CH.UTF-8 de_DE.UTF-8
-NLSLINKS_el_GR.ISO8859-7 = el_GR.UTF-8
-NLSLINKS_es_ES.ISO8859-1 += es_ES.UTF-8
-NLSLINKS_et_EE.ISO8859-15 = et_EE.UTF-8
-NLSLINKS_fi_FI.ISO8859-1 += fi_FI.UTF-8
-NLSLINKS_fr_FR.ISO8859-1 += fr_BE.UTF-8 fr_CA.UTF-8 fr_CH.UTF-8 fr_FR.UTF-8
-NLSLINKS_it_IT.ISO8859-1 += it_CH.UTF-8 it_IT.UTF-8
-NLSLINKS_ja_JP.eucJP = ja_JP.SJIS ja_JP.UTF-8
-NLSLINKS_ru_RU.KOI8-R = ru_RU.CP1251 ru_RU.CP866 ru_RU.ISO8859-5 ru_RU.UTF-8
-NLSLINKS_uk_UA.KOI8-U = uk_UA.ISO8859-5 uk_UA.UTF-8
+NLSLINKS_de_DE.UTF-8 += de_AT.ISO8859-1 de_AT.ISO8859-15 de_CH.ISO8859-1 \
+   de_CH.ISO8859-15 de_DE.ISO8859-1 de_DE.ISO8859-15
+NLSLINKS_el_GR.UTF-8 = el_GR.ISO8859-7
+NLSLINKS_es_ES.UTF-8 = es_ES.ISO8859-1 es_ES.ISO8859-15
+NLSLINKS_et_EE.UTF-8 = et_EE.ISO8859-15
+NLSLINKS_fi_FI.UTF-8 = fi_FI.ISO8859-1 fi_FI.ISO8859-15
+NLSLINKS_fr_FR.UTF-8 += fr_BE.ISO8859-1 fr_BE.ISO8859-15 \
+   fr_CA.ISO8859-1 fr_CA.ISO8859-15 fr_CH.ISO8859-1 \
+   fr_CH.ISO8859-15 fr_FR.ISO8859-1 fr_FR.ISO8859-15
+NLSLINKS_it_IT.UTF-8 += it_CH.ISO8859-1 it_CH.ISO8859-15 it_IT.ISO8859-1 \
+   it_IT.ISO8859-15
+NLSLINKS_ja_JP.UTF-8 = ja_JP.SJIS ja_JP.eucJP
+NLSLINKS_ru_RU.UTF-8 = ru_RU.CP1251 ru_RU.CP866 ru_RU.ISO8859-5 ru_RU.KOI8-R
+NLSLINKS_uk_UA.UTF-8 = uk_UA.ISO8859-5 uk_UA.KOI8-U
 .else
 # Above links can be installed from ports/shells/tcsh_nls
 
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


svn commit: r295206 - in head/sys/arm: arm include

2016-02-03 Thread Svatopluk Kraus
Author: skra
Date: Wed Feb  3 12:11:07 2016
New Revision: 295206
URL: https://svnweb.freebsd.org/changeset/base/295206

Log:
  Partly revert r295168 and define PTE_DEVICE in pmap-v6.h header again.
  It turned out that devmap.c is not only file in which PTE_DEVICE
  is used and simultaneously, built for both armv4 and armv6 platforms.
  
  When I tried to build all arm kernels before r295168 commit, it was
  hid by some other local changes in my tree. I hope that this is just
  temporary workaround before VM_MEMATTR_DEVICE could be used instead of
  PTE_DEVICE outside of pmap code for __ARM_ARCH < 6.

Modified:
  head/sys/arm/arm/devmap.c
  head/sys/arm/include/pmap-v6.h

Modified: head/sys/arm/arm/devmap.c
==
--- head/sys/arm/arm/devmap.c   Wed Feb  3 11:49:51 2016(r295205)
+++ head/sys/arm/arm/devmap.c   Wed Feb  3 12:11:07 2016(r295206)
@@ -55,9 +55,6 @@ static boolean_t devmap_bootstrap_done =
 #definePTE_DEVICE  VM_MEMATTR_DEVICE
 #elif defined(__arm__)
 #defineMAX_VADDR   ARM_VECTORS_HIGH
-#if __ARM_ARCH >= 6
-#definePTE_DEVICE  VM_MEMATTR_DEVICE
-#endif
 #endif
 
 /*

Modified: head/sys/arm/include/pmap-v6.h
==
--- head/sys/arm/include/pmap-v6.h  Wed Feb  3 11:49:51 2016
(r295205)
+++ head/sys/arm/include/pmap-v6.h  Wed Feb  3 12:11:07 2016
(r295206)
@@ -250,6 +250,8 @@ void pmap_preboot_map_attr(vm_paddr_t, v
  */
 void vector_page_setprot(int);
 
+#define PTE_DEVICE VM_MEMATTR_DEVICE
+
 #endif /* _KERNEL */
 // 
-
 
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


Re: svn commit: r295160 - stable/7/sys/kern

2016-02-03 Thread Bruce Evans

On Tue, 2 Feb 2016, John Baldwin wrote:


Log:
 Return the timestamps from the corresponding namecache entry on a negative
 namecache hit.  This was ommitted due to a merging error in r238913.  The
 effect was to usually break caching of negative name lookups in the NFS
 client.

 Submitted by:  bde


Thanks.  FreeBSD-7 is now almost the fastest version in my makeworld on
nfs benchmark :-).

Bruce
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


svn commit: r295203 - stable/9/bin/csh

2016-02-03 Thread Hajimu UMEMOTO
Author: ume
Date: Wed Feb  3 11:41:55 2016
New Revision: 295203
URL: https://svnweb.freebsd.org/changeset/base/295203

Log:
  MFC r295147:
Make dynamic link of libiconv from ports work again.
The symbols of libiconv from ports were changed to
have prefixed.
Since we have iconv in our libc these days, we don't
need it on 10.X and later.  However, 9.X still need
this.

Modified:
  stable/9/bin/csh/iconv_stub.c
Directory Properties:
  stable/9/bin/csh/   (props changed)

Modified: stable/9/bin/csh/iconv_stub.c
==
--- stable/9/bin/csh/iconv_stub.c   Wed Feb  3 11:03:44 2016
(r295202)
+++ stable/9/bin/csh/iconv_stub.c   Wed Feb  3 11:41:55 2016
(r295203)
@@ -36,9 +36,9 @@
 #undef iconv_close
 
 #define ICONVLIB   "libiconv.so"
-#define ICONV_ENGINE   "iconv"
-#define ICONV_OPEN "iconv_open"
-#define ICONV_CLOSE"iconv_close"
+#define ICONV_ENGINE   "libiconv"
+#define ICONV_OPEN "libiconv_open"
+#define ICONV_CLOSE"libiconv_close"
 
 typedef iconv_t iconv_open_t(const char *, const char *);
 
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


svn commit: r295218 - head/sys/dev/cxgb

2016-02-03 Thread Gleb Smirnoff
Author: glebius
Date: Wed Feb  3 20:39:52 2016
New Revision: 295218
URL: https://svnweb.freebsd.org/changeset/base/295218

Log:
  Fix inverse logic. If this is zone_pack, then we shouldn't free the
  cluster ourselves.
  
  Found by review. Since this code is !386 and !amd64 and is executed
  on error path, pretty sure no one ever executed it.

Modified:
  head/sys/dev/cxgb/cxgb_sge.c

Modified: head/sys/dev/cxgb/cxgb_sge.c
==
--- head/sys/dev/cxgb/cxgb_sge.cWed Feb  3 20:24:21 2016
(r295217)
+++ head/sys/dev/cxgb/cxgb_sge.cWed Feb  3 20:39:52 2016
(r295218)
@@ -738,7 +738,7 @@ refill_fl(adapter_t *sc, struct sge_fl *
cl, q->buf_size, refill_fl_cb, _arg, 0);

if (err != 0 || cb_arg.error) {
-   if (q->zone == zone_pack)
+   if (q->zone != zone_pack)
uma_zfree(q->zone, cl);
m_free(m);
goto done;
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


svn commit: r295217 - head

2016-02-03 Thread Bryan Drewery
Author: bdrewery
Date: Wed Feb  3 20:24:21 2016
New Revision: 295217
URL: https://svnweb.freebsd.org/changeset/base/295217

Log:
  Deduplicate distrib-dirs logic from r289086 in distribution.
  
  This does it correctly this time, rather than the incorrect version in
  r295167.
  
  Sponsored by: EMC / Isilon Storage Division

Modified:
  head/Makefile.inc1

Modified: head/Makefile.inc1
==
--- head/Makefile.inc1  Wed Feb  3 19:08:45 2016(r295216)
+++ head/Makefile.inc1  Wed Feb  3 20:24:21 2016(r295217)
@@ -1083,16 +1083,14 @@ redistribute: .MAKE .PHONY
DISTRIBUTION=lib32
 .endif
 
-distrib-dirs: .MAKE .PHONY
-   ${_+_}cd ${.CURDIR}/etc; ${CROSSENV} PATH=${TMPPATH} ${MAKE} \
-   ${IMAKE_INSTALL} ${IMAKE_MTREE} METALOG=${METALOG} ${.TARGET}
-
-distribution: .MAKE .PHONY
+distrib-dirs distribution: .MAKE .PHONY
${_+_}cd ${.CURDIR}/etc; ${CROSSENV} PATH=${TMPPATH} ${MAKE} \
${IMAKE_INSTALL} ${IMAKE_MTREE} METALOG=${METALOG} ${.TARGET}
+.if make(distribution)
${_+_}cd ${.CURDIR}; ${CROSSENV} PATH=${TMPPATH} \
${MAKE} -f Makefile.inc1 ${IMAKE_INSTALL} \
METALOG=${METALOG} installconfig
+.endif
 
 #
 # buildkernel and installkernel
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


svn commit: r295221 - in head/sys: kern vm

2016-02-03 Thread Gleb Smirnoff
Author: glebius
Date: Wed Feb  3 22:02:36 2016
New Revision: 295221
URL: https://svnweb.freebsd.org/changeset/base/295221

Log:
  Move uma_dbg_alloc() and uma_dbg_free() into uma_core.c, which allows
  to make uma_dbg.h not depend on uma_int.h, which allows to uninclude
  uma_int.h from the mbuf(9) allocator.

Modified:
  head/sys/kern/kern_mbuf.c
  head/sys/vm/uma_core.c
  head/sys/vm/uma_dbg.c
  head/sys/vm/uma_dbg.h

Modified: head/sys/kern/kern_mbuf.c
==
--- head/sys/kern/kern_mbuf.c   Wed Feb  3 21:56:51 2016(r295220)
+++ head/sys/kern/kern_mbuf.c   Wed Feb  3 22:02:36 2016(r295221)
@@ -52,7 +52,6 @@ __FBSDID("$FreeBSD$");
 #include 
 #include 
 #include 
-#include 
 #include 
 
 /*

Modified: head/sys/vm/uma_core.c
==
--- head/sys/vm/uma_core.c  Wed Feb  3 21:56:51 2016(r295220)
+++ head/sys/vm/uma_core.c  Wed Feb  3 22:02:36 2016(r295221)
@@ -275,6 +275,11 @@ void uma_print_stats(void);
 static int sysctl_vm_zone_count(SYSCTL_HANDLER_ARGS);
 static int sysctl_vm_zone_stats(SYSCTL_HANDLER_ARGS);
 
+#ifdef INVARIANTS
+static void uma_dbg_free(uma_zone_t zone, uma_slab_t slab, void *item);
+static void uma_dbg_alloc(uma_zone_t zone, uma_slab_t slab, void *item);
+#endif
+
 SYSINIT(uma_startup3, SI_SUB_VM_CONF, SI_ORDER_SECOND, uma_startup3, NULL);
 
 SYSCTL_PROC(_vm, OID_AUTO, zone_count, CTLFLAG_RD|CTLTYPE_INT,
@@ -3607,6 +3612,102 @@ sysctl_handle_uma_zone_cur(SYSCTL_HANDLE
return (sysctl_handle_int(oidp, , 0, req));
 }
 
+#ifdef INVARIANTS
+static uma_slab_t
+uma_dbg_getslab(uma_zone_t zone, void *item)
+{
+   uma_slab_t slab;
+   uma_keg_t keg;
+   uint8_t *mem;
+
+   mem = (uint8_t *)((uintptr_t)item & (~UMA_SLAB_MASK));
+   if (zone->uz_flags & UMA_ZONE_VTOSLAB) {
+   slab = vtoslab((vm_offset_t)mem);
+   } else {
+   /*
+* It is safe to return the slab here even though the
+* zone is unlocked because the item's allocation state
+* essentially holds a reference.
+*/
+   ZONE_LOCK(zone);
+   keg = LIST_FIRST(>uz_kegs)->kl_keg;
+   if (keg->uk_flags & UMA_ZONE_HASH)
+   slab = hash_sfind(>uk_hash, mem);
+   else
+   slab = (uma_slab_t)(mem + keg->uk_pgoff);
+   ZONE_UNLOCK(zone);
+   }
+
+   return (slab);
+}
+
+/*
+ * Set up the slab's freei data such that uma_dbg_free can function.
+ *
+ */
+static void
+uma_dbg_alloc(uma_zone_t zone, uma_slab_t slab, void *item)
+{
+   uma_keg_t keg;
+   int freei;
+
+   if (zone_first_keg(zone) == NULL)
+   return;
+   if (slab == NULL) {
+   slab = uma_dbg_getslab(zone, item);
+   if (slab == NULL) 
+   panic("uma: item %p did not belong to zone %s\n",
+   item, zone->uz_name);
+   }
+   keg = slab->us_keg;
+   freei = ((uintptr_t)item - (uintptr_t)slab->us_data) / keg->uk_rsize;
+
+   if (BIT_ISSET(SLAB_SETSIZE, freei, >us_debugfree))
+   panic("Duplicate alloc of %p from zone %p(%s) slab %p(%d)\n",
+   item, zone, zone->uz_name, slab, freei);
+   BIT_SET_ATOMIC(SLAB_SETSIZE, freei, >us_debugfree);
+
+   return;
+}
+
+/*
+ * Verifies freed addresses.  Checks for alignment, valid slab membership
+ * and duplicate frees.
+ *
+ */
+static void
+uma_dbg_free(uma_zone_t zone, uma_slab_t slab, void *item)
+{
+   uma_keg_t keg;
+   int freei;
+
+   if (zone_first_keg(zone) == NULL)
+   return;
+   if (slab == NULL) {
+   slab = uma_dbg_getslab(zone, item);
+   if (slab == NULL) 
+   panic("uma: Freed item %p did not belong to zone %s\n",
+   item, zone->uz_name);
+   }
+   keg = slab->us_keg;
+   freei = ((uintptr_t)item - (uintptr_t)slab->us_data) / keg->uk_rsize;
+
+   if (freei >= keg->uk_ipers)
+   panic("Invalid free of %p from zone %p(%s) slab %p(%d)\n",
+   item, zone, zone->uz_name, slab, freei);
+
+   if (((freei * keg->uk_rsize) + slab->us_data) != item) 
+   panic("Unaligned free of %p from zone %p(%s) slab %p(%d)\n",
+   item, zone, zone->uz_name, slab, freei);
+
+   if (!BIT_ISSET(SLAB_SETSIZE, freei, >us_debugfree))
+   panic("Duplicate free of %p from zone %p(%s) slab %p(%d)\n",
+   item, zone, zone->uz_name, slab, freei);
+
+   BIT_CLR_ATOMIC(SLAB_SETSIZE, freei, >us_debugfree);
+}
+#endif /* INVARIANTS */
+
 #ifdef DDB
 DB_SHOW_COMMAND(uma, db_show_uma)
 {
@@ -3664,4 +3765,4 @@ DB_SHOW_COMMAND(umacache, db_show_umacac
return;
}
 }
-#endif
+#endif /* DDB */

svn commit: r295208 - stable/10/sys/netinet

2016-02-03 Thread Michael Tuexen
Author: tuexen
Date: Wed Feb  3 14:04:07 2016
New Revision: 295208
URL: https://svnweb.freebsd.org/changeset/base/295208

Log:
  MFC r294995:
  Always look in the TCP pool.
  This fixes issues with a restarting peer when the listening
  1-to-1 style socket is closed.
  
  MFC r295021:
  Remove debug output which was committed by accident.
  Thanks to Oliver Pinter for reporting.
  
  MFC r295069:
  Ignore peer addresses in a consistent way also when checking for
  new addresses during restart. If this is not done, restart doesn't
  work when the local socket is IPv4 only and the peer uses
  IPv4 and IPv6 addresses.
  
  MFC r295070:
  Don't change the remote UDP encapsulation port for SCTP packets
  containing an INIT chunk.
  
  MFC r295072:
  Don't allow a remote encapsulation port change during the
  SCTP restart procedure.
  
  MFC r295075:
  Update the path mtu when turning on/off UDP encapsulation for SCTP.
  
  MFC r295077:
  Add missing parentheses. This was reported by ccaughie via GitHub
  for the userland stack.
  
  Approved by: re (kib)

Modified:
  stable/10/sys/netinet/sctp_input.c
  stable/10/sys/netinet/sctp_output.c
  stable/10/sys/netinet/sctp_output.h
  stable/10/sys/netinet/sctp_pcb.c
  stable/10/sys/netinet/sctp_var.h
Directory Properties:
  stable/10/   (props changed)

Modified: stable/10/sys/netinet/sctp_input.c
==
--- stable/10/sys/netinet/sctp_input.c  Wed Feb  3 13:47:50 2016
(r295207)
+++ stable/10/sys/netinet/sctp_input.c  Wed Feb  3 14:04:07 2016
(r295208)
@@ -85,7 +85,7 @@ static void
 sctp_handle_init(struct mbuf *m, int iphlen, int offset,
 struct sockaddr *src, struct sockaddr *dst, struct sctphdr *sh,
 struct sctp_init_chunk *cp, struct sctp_inpcb *inp,
-struct sctp_tcb *stcb, int *abort_no_unlock,
+struct sctp_tcb *stcb, struct sctp_nets *net, int *abort_no_unlock,
 uint8_t mflowtype, uint32_t mflowid,
 uint32_t vrf_id, uint16_t port)
 {
@@ -198,8 +198,8 @@ sctp_handle_init(struct mbuf *m, int iph
sctp_chunk_output(inp, stcb, SCTP_OUTPUT_FROM_CONTROL_PROC, 
SCTP_SO_NOT_LOCKED);
} else {
SCTPDBG(SCTP_DEBUG_INPUT3, "sctp_handle_init: sending 
INIT-ACK\n");
-   sctp_send_initiate_ack(inp, stcb, m, iphlen, offset, src, dst,
-   sh, cp,
+   sctp_send_initiate_ack(inp, stcb, net, m, iphlen, offset,
+   src, dst, sh, cp,
mflowtype, mflowid,
vrf_id, port,
((stcb == NULL) ? SCTP_HOLDS_LOCK : SCTP_NOT_LOCKED));
@@ -4840,7 +4840,7 @@ process_control_chunks:
}
sctp_handle_init(m, iphlen, *offset, src, dst, sh,
(struct sctp_init_chunk *)ch, inp,
-   stcb, _no_unlock,
+   stcb, *netp, _no_unlock,
mflowtype, mflowid,
vrf_id, port);
*offset = length;
@@ -5684,9 +5684,18 @@ sctp_common_input_processing(struct mbuf
stcb = sctp_findassociation_addr(m, offset, src, dst,
sh, ch, , , vrf_id);
 #if defined(INET) || defined(INET6)
-   if ((net != NULL) && (port != 0)) {
+   if ((ch->chunk_type != SCTP_INITIATION) &&
+   (net != NULL) && (net->port != port)) {
if (net->port == 0) {
-   sctp_pathmtu_adjustment(stcb, net->mtu 
- sizeof(struct udphdr));
+   /* UDP encapsulation turned on. */
+   net->mtu -= sizeof(struct udphdr);
+   if (stcb->asoc.smallest_mtu > net->mtu) 
{
+   sctp_pathmtu_adjustment(stcb, 
net->mtu);
+   }
+   } else if (port == 0) {
+   /* UDP encapsulation turned off. */
+   net->mtu += sizeof(struct udphdr);
+   /* XXX Update smallest_mtu */
}
net->port = port;
}
@@ -5715,9 +5724,18 @@ sctp_common_input_processing(struct mbuf
stcb = sctp_findassociation_addr(m, offset, src, dst,
sh, ch, , , vrf_id);
 #if defined(INET) || defined(INET6)
-   if ((net != NULL) && (port != 0)) {
+   if ((ch->chunk_type != SCTP_INITIATION) &&
+   (net != NULL) && (net->port != port)) {
if (net->port == 0) {
-   sctp_pathmtu_adjustment(stcb, net->mtu - sizeof(struct 
udphdr));
+   /* UDP encapsulation turned on. */
+   net->mtu -= 

svn commit: r295209 - head/sys/fs/ext2fs

2016-02-03 Thread Pedro F. Giffuni
Author: pfg
Date: Wed Feb  3 14:31:23 2016
New Revision: 295209
URL: https://svnweb.freebsd.org/changeset/base/295209

Log:
  Revert r294695:
  ext2fs: passthrough any extra timestamps to the dinode struct.
  
  While it passed the classic testing, the change appears to have
  caused some regression and still requires some more precautions.
  
  PR:   206820
  MFC after:3 days

Modified:
  head/sys/fs/ext2fs/ext2_inode_cnv.c

Modified: head/sys/fs/ext2fs/ext2_inode_cnv.c
==
--- head/sys/fs/ext2fs/ext2_inode_cnv.c Wed Feb  3 14:04:07 2016
(r295208)
+++ head/sys/fs/ext2fs/ext2_inode_cnv.c Wed Feb  3 14:31:23 2016
(r295209)
@@ -149,11 +149,13 @@ ext2_i2ei(struct inode *ip, struct ext2f
ei->e2di_atime = ip->i_atime;
ei->e2di_mtime = ip->i_mtime;
ei->e2di_ctime = ip->i_ctime;
-   ei->e2di_ctime_extra = NSEC_TO_XTIME(ip->i_ctimensec);
-   ei->e2di_mtime_extra = NSEC_TO_XTIME(ip->i_mtimensec);
-   ei->e2di_atime_extra = NSEC_TO_XTIME(ip->i_atimensec);
-   ei->e2di_crtime = ip->i_birthtime;
-   ei->e2di_crtime_extra = NSEC_TO_XTIME(ip->i_birthnsec);
+   if (E2DI_HAS_XTIME(ip)) {
+   ei->e2di_ctime_extra = NSEC_TO_XTIME(ip->i_ctimensec);
+   ei->e2di_mtime_extra = NSEC_TO_XTIME(ip->i_mtimensec);
+   ei->e2di_atime_extra = NSEC_TO_XTIME(ip->i_atimensec);
+   ei->e2di_crtime = ip->i_birthtime;
+   ei->e2di_crtime_extra = NSEC_TO_XTIME(ip->i_birthnsec);
+   }
ei->e2di_flags = 0;
ei->e2di_flags |= (ip->i_flags & SF_APPEND) ? EXT2_APPEND: 0;
ei->e2di_flags |= (ip->i_flags & SF_IMMUTABLE) ? EXT2_IMMUTABLE: 0;
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


svn commit: r295210 - head/sys/boot/efi/libefi

2016-02-03 Thread Andrew Turner
Author: andrew
Date: Wed Feb  3 14:34:25 2016
New Revision: 295210
URL: https://svnweb.freebsd.org/changeset/base/295210

Log:
  Still open the network interface when EFI_OPEN_PROTOCOL_EXCLUSIVE failed.
  Not all UEFI implementations support this protocol.

Modified:
  head/sys/boot/efi/libefi/efinet.c

Modified: head/sys/boot/efi/libefi/efinet.c
==
--- head/sys/boot/efi/libefi/efinet.c   Wed Feb  3 14:31:23 2016
(r295209)
+++ head/sys/boot/efi/libefi/efinet.c   Wed Feb  3 14:34:25 2016
(r295210)
@@ -309,8 +309,8 @@ efinet_dev_init()
status = BS->OpenProtocol(h, _guid, (void **),
IH, 0, EFI_OPEN_PROTOCOL_EXCLUSIVE);
if (status != EFI_SUCCESS) {
-   printf("Unable to open network interface %d\n", i);
-   continue;
+   printf("Unable to open network interface %d for "
+   "exclusive access\n", i);
}
 
dif->dif_unit = i;
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


svn commit: r295211 - stable/10/sys/dev/pty

2016-02-03 Thread Konstantin Belousov
Author: kib
Date: Wed Feb  3 15:16:20 2016
New Revision: 295211
URL: https://svnweb.freebsd.org/changeset/base/295211

Log:
  MFC r293825:
  Switch legacy pty clone handler to use make_dev_s(9).
  
  MFC r294594:
  Remove printf only useful for debugging.
  
  Approved by:  re (marius)

Modified:
  stable/10/sys/dev/pty/pty.c
Directory Properties:
  stable/10/   (props changed)

Modified: stable/10/sys/dev/pty/pty.c
==
--- stable/10/sys/dev/pty/pty.c Wed Feb  3 14:34:25 2016(r295210)
+++ stable/10/sys/dev/pty/pty.c Wed Feb  3 15:16:20 2016(r295211)
@@ -97,6 +97,8 @@ static void
 pty_clone(void *arg, struct ucred *cr, char *name, int namelen,
 struct cdev **dev)
 {
+   struct make_dev_args mda;
+   int error;
 
/* Cloning is already satisfied. */
if (*dev != NULL)
@@ -117,8 +119,15 @@ pty_clone(void *arg, struct ucred *cr, c
return;
 
/* Create the controller device node. */
-   *dev = make_dev_credf(MAKEDEV_REF, _cdevsw, 0,
-   NULL, UID_ROOT, GID_WHEEL, 0666, "%s", name);
+   make_dev_args_init();
+   mda.mda_flags =  MAKEDEV_CHECKNAME | MAKEDEV_REF;
+   mda.mda_devsw = _cdevsw;
+   mda.mda_uid = UID_ROOT;
+   mda.mda_gid = GID_WHEEL;
+   mda.mda_mode = 0666;
+   error = make_dev_s(, dev, "%s", name);
+   if (error != 0)
+   *dev = NULL;
 }
 
 static int
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


Re: svn commit: r295204 - head/bin/csh

2016-02-03 Thread Bryan Drewery
On 2/3/2016 3:44 AM, Hajimu UMEMOTO wrote:
> Author: ume
> Date: Wed Feb  3 11:44:43 2016
> New Revision: 295204
> URL: https://svnweb.freebsd.org/changeset/base/295204
> 
> Log:
>   The charset of NLS catalogs were converted to UTF-8
>   since r231990.
> 
> Modified:
>   head/bin/csh/Makefile
> 
> Modified: head/bin/csh/Makefile
> ==
> --- head/bin/csh/Makefile Wed Feb  3 11:41:55 2016(r295203)
> +++ head/bin/csh/Makefile Wed Feb  3 11:44:43 2016(r295204)
> @@ -51,41 +51,40 @@ FILESDIR= ${SHAREDIR}/examples/tcsh
>  FILES= complete.tcsh csh-mode.el
>  .endif
>  
> -CATALOGS=et:et_EE.ISO8859-15 \
> - finnish:fi_FI.ISO8859-1 \
> - french:fr_FR.ISO8859-1 \
> - german:de_DE.ISO8859-1 \
> - greek:el_GR.ISO8859-7 \
> - italian:it_IT.ISO8859-1 \
> - ja:ja_JP.eucJP \
> - russian:ru_RU.KOI8-R \
> - spanish:es_ES.ISO8859-1 \
> - ukrainian:uk_UA.KOI8-U
> -
> -NLSLINKS_fi_FI.ISO8859-1= fi_FI.ISO8859-15
> -NLSLINKS_fr_FR.ISO8859-1= fr_BE.ISO8859-1 fr_BE.ISO8859-15 \
> - fr_CA.ISO8859-1 fr_CA.ISO8859-15 fr_CH.ISO8859-1 \
> - fr_CH.ISO8859-15 fr_FR.ISO8859-15
> -NLSLINKS_de_DE.ISO8859-1= de_AT.ISO8859-1 de_AT.ISO8859-15 de_CH.ISO8859-1 \
> - de_CH.ISO8859-15 de_DE.ISO8859-15
> -NLSLINKS_it_IT.ISO8859-1= it_CH.ISO8859-1 it_CH.ISO8859-15 it_IT.ISO8859-15
> -NLSLINKS_es_ES.ISO8859-1= es_ES.ISO8859-15
> +CATALOGS=et:et_EE.UTF-8 \
> + finnish:fi_FI.UTF-8 \
> + french:fr_FR.UTF-8 \
> + german:de_DE.UTF-8 \
> + greek:el_GR.UTF-8 \
> + italian:it_IT.UTF-8 \
> + ja:ja_JP.UTF-8 \
> + russian:ru_RU.UTF-8 \
> + spanish:es_ES.UTF-8 \
> + ukrainian:uk_UA.UTF-8
> +
> +NLSLINKS_de_DE.UTF-8 = de_AT.UTF-8 de_CH.UTF-8 de_DE.UTF-8

This is linking /usr/share/nls/de_DE.UTF-8/tcsh.cat to itself. I removed
that in r295224. I'm not sure if it should be linked to something else
though.

-- 
Regards,
Bryan Drewery



signature.asc
Description: OpenPGP digital signature


svn commit: r295224 - head/bin/csh

2016-02-03 Thread Bryan Drewery
Author: bdrewery
Date: Wed Feb  3 23:37:24 2016
New Revision: 295224
URL: https://svnweb.freebsd.org/changeset/base/295224

Log:
  Don't link /usr/share/nls/de_DE.UTF-8/tcsh.cat to itself.
  
  Sponsored by: EMC / Isilon Storage Division

Modified:
  head/bin/csh/Makefile

Modified: head/bin/csh/Makefile
==
--- head/bin/csh/Makefile   Wed Feb  3 23:37:14 2016(r295223)
+++ head/bin/csh/Makefile   Wed Feb  3 23:37:24 2016(r295224)
@@ -62,7 +62,7 @@ CATALOGS= et:et_EE.UTF-8 \
spanish:es_ES.UTF-8 \
ukrainian:uk_UA.UTF-8
 
-NLSLINKS_de_DE.UTF-8 = de_AT.UTF-8 de_CH.UTF-8 de_DE.UTF-8
+NLSLINKS_de_DE.UTF-8 = de_AT.UTF-8 de_CH.UTF-8
 NLSLINKS_fr_FR.UTF-8 = fr_BE.UTF-8 fr_CA.UTF-8 fr_CH.UTF-8
 NLSLINKS_it_IT.UTF-8 = it_CH.UTF-8
 
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


svn commit: r295223 - head/share/mk

2016-02-03 Thread Bryan Drewery
Author: bdrewery
Date: Wed Feb  3 23:37:14 2016
New Revision: 295223
URL: https://svnweb.freebsd.org/changeset/base/295223

Log:
  Don't let NLSLINKS contain itself.
  
  Sponsored by: EMC / Isilon Storage Division

Modified:
  head/share/mk/bsd.nls.mk

Modified: head/share/mk/bsd.nls.mk
==
--- head/share/mk/bsd.nls.mkWed Feb  3 23:30:17 2016(r295222)
+++ head/share/mk/bsd.nls.mkWed Feb  3 23:37:14 2016(r295223)
@@ -73,6 +73,9 @@ SYMLINKS+= ${NLSSYMLINKS}
 .for file in ${NLS}
 NLSNAME_${file:T}= ${file:T:R}/${NLSNAME}.cat
 .if defined(NLSLINKS_${file:R}) && !empty(NLSLINKS_${file:R})
+.if !empty(NLSLINKS_${file:R}:M${file:R})
+.error NLSLINKS_${file:R} contains itself: ${file:R}
+.endif
 NLSLINKS+= ${file:R}
 .endif
 .for dst in ${NLSLINKS_${file:R}}
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


Re: svn commit: r295226 - head/lib/libmemstat

2016-02-03 Thread Bryan Drewery
On 2/3/2016 4:23 PM, Gleb Smirnoff wrote:
> Author: glebius
> Date: Thu Feb  4 00:23:21 2016
> New Revision: 295226
> URL: https://svnweb.freebsd.org/changeset/base/295226
> 
> Log:
>   Fix build.
> 
> Modified:
>   head/lib/libmemstat/memstat_uma.c
> 
> Modified: head/lib/libmemstat/memstat_uma.c
> ==
> --- head/lib/libmemstat/memstat_uma.c Wed Feb  3 23:41:58 2016
> (r295225)
> +++ head/lib/libmemstat/memstat_uma.c Thu Feb  4 00:23:21 2016
> (r295226)
> @@ -29,6 +29,7 @@
>  #include 
>  #include 
>  #include 
> +#include 
>  
>  #include 
>  #include 
> 

Shouldn't uma_int.h forward declare or include _task.h for struct task?

-- 
Regards,
Bryan Drewery



signature.asc
Description: OpenPGP digital signature


svn commit: r295222 - in head/sys: amd64/amd64 kern vm

2016-02-03 Thread Gleb Smirnoff
Author: glebius
Date: Wed Feb  3 23:30:17 2016
New Revision: 295222
URL: https://svnweb.freebsd.org/changeset/base/295222

Log:
  Redo r292484. Embed task(9) into zone, so that uz_maxaction is called
  in a context that can sleep, allowing consumers of the KPI to run their
  drain routines without any extra measures.
  
  Discussed with:   jtl

Modified:
  head/sys/amd64/amd64/uma_machdep.c
  head/sys/kern/kern_malloc.c
  head/sys/kern/kern_mbuf.c
  head/sys/vm/memguard.c
  head/sys/vm/uma.h
  head/sys/vm/uma_core.c
  head/sys/vm/uma_dbg.c
  head/sys/vm/uma_int.h
  head/sys/vm/vm_page.c

Modified: head/sys/amd64/amd64/uma_machdep.c
==
--- head/sys/amd64/amd64/uma_machdep.c  Wed Feb  3 22:02:36 2016
(r295221)
+++ head/sys/amd64/amd64/uma_machdep.c  Wed Feb  3 23:30:17 2016
(r295222)
@@ -32,6 +32,7 @@ __FBSDID("$FreeBSD$");
 #include 
 #include 
 #include 
+#include 
 #include 
 #include 
 #include 

Modified: head/sys/kern/kern_malloc.c
==
--- head/sys/kern/kern_malloc.c Wed Feb  3 22:02:36 2016(r295221)
+++ head/sys/kern/kern_malloc.c Wed Feb  3 23:30:17 2016(r295222)
@@ -59,6 +59,7 @@ __FBSDID("$FreeBSD$");
 #include 
 #include 
 #include 
+#include 
 #include 
 #include 
 

Modified: head/sys/kern/kern_mbuf.c
==
--- head/sys/kern/kern_mbuf.c   Wed Feb  3 22:02:36 2016(r295221)
+++ head/sys/kern/kern_mbuf.c   Wed Feb  3 23:30:17 2016(r295222)
@@ -274,12 +274,6 @@ uma_zone_t zone_jumbo16;
 uma_zone_t zone_ext_refcnt;
 
 /*
- * Callout to assist us in freeing mbufs.
- */
-static struct callout  mb_reclaim_callout;
-static struct mtx  mb_reclaim_callout_mtx;
-
-/*
  * Local prototypes.
  */
 static int mb_ctor_mbuf(void *, int, void *, int);
@@ -291,9 +285,8 @@ static void mb_dtor_pack(void *, int, vo
 static int mb_zinit_pack(void *, int, int);
 static voidmb_zfini_pack(void *, int);
 
-static voidmb_reclaim(void *);
+static voidmb_reclaim(uma_zone_t, int);
 static void*mbuf_jumbo_alloc(uma_zone_t, vm_size_t, uint8_t *, int);
-static voidmb_maxaction(uma_zone_t);
 
 /* Ensure that MSIZE is a power of 2. */
 CTASSERTMSIZE - 1) ^ MSIZE) + 1) >> 1 == MSIZE);
@@ -319,7 +312,7 @@ mbuf_init(void *dummy)
if (nmbufs > 0)
nmbufs = uma_zone_set_max(zone_mbuf, nmbufs);
uma_zone_set_warning(zone_mbuf, "kern.ipc.nmbufs limit reached");
-   uma_zone_set_maxaction(zone_mbuf, mb_maxaction);
+   uma_zone_set_maxaction(zone_mbuf, mb_reclaim);
 
zone_clust = uma_zcreate(MBUF_CLUSTER_MEM_NAME, MCLBYTES,
mb_ctor_clust, mb_dtor_clust,
@@ -332,7 +325,7 @@ mbuf_init(void *dummy)
if (nmbclusters > 0)
nmbclusters = uma_zone_set_max(zone_clust, nmbclusters);
uma_zone_set_warning(zone_clust, "kern.ipc.nmbclusters limit reached");
-   uma_zone_set_maxaction(zone_clust, mb_maxaction);
+   uma_zone_set_maxaction(zone_clust, mb_reclaim);
 
zone_pack = uma_zsecond_create(MBUF_PACKET_MEM_NAME, mb_ctor_pack,
mb_dtor_pack, mb_zinit_pack, mb_zfini_pack, zone_mbuf);
@@ -349,7 +342,7 @@ mbuf_init(void *dummy)
if (nmbjumbop > 0)
nmbjumbop = uma_zone_set_max(zone_jumbop, nmbjumbop);
uma_zone_set_warning(zone_jumbop, "kern.ipc.nmbjumbop limit reached");
-   uma_zone_set_maxaction(zone_jumbop, mb_maxaction);
+   uma_zone_set_maxaction(zone_jumbop, mb_reclaim);
 
zone_jumbo9 = uma_zcreate(MBUF_JUMBO9_MEM_NAME, MJUM9BYTES,
mb_ctor_clust, mb_dtor_clust,
@@ -363,7 +356,7 @@ mbuf_init(void *dummy)
if (nmbjumbo9 > 0)
nmbjumbo9 = uma_zone_set_max(zone_jumbo9, nmbjumbo9);
uma_zone_set_warning(zone_jumbo9, "kern.ipc.nmbjumbo9 limit reached");
-   uma_zone_set_maxaction(zone_jumbo9, mb_maxaction);
+   uma_zone_set_maxaction(zone_jumbo9, mb_reclaim);
 
zone_jumbo16 = uma_zcreate(MBUF_JUMBO16_MEM_NAME, MJUM16BYTES,
mb_ctor_clust, mb_dtor_clust,
@@ -377,20 +370,13 @@ mbuf_init(void *dummy)
if (nmbjumbo16 > 0)
nmbjumbo16 = uma_zone_set_max(zone_jumbo16, nmbjumbo16);
uma_zone_set_warning(zone_jumbo16, "kern.ipc.nmbjumbo16 limit reached");
-   uma_zone_set_maxaction(zone_jumbo16, mb_maxaction);
+   uma_zone_set_maxaction(zone_jumbo16, mb_reclaim);
 
zone_ext_refcnt = uma_zcreate(MBUF_EXTREFCNT_MEM_NAME, sizeof(u_int),
NULL, NULL,
NULL, NULL,
UMA_ALIGN_PTR, UMA_ZONE_ZINIT);
 
-   /* uma_prealloc() goes here... */
-
-   /* Initialize the mb_reclaim() callout. */
-   mtx_init(_reclaim_callout_mtx, "mb_reclaim_callout_mtx", NULL,
-   MTX_DEF);
-   callout_init(_reclaim_callout, 1);
-
/*
 * Hook 

svn commit: r295226 - head/lib/libmemstat

2016-02-03 Thread Gleb Smirnoff
Author: glebius
Date: Thu Feb  4 00:23:21 2016
New Revision: 295226
URL: https://svnweb.freebsd.org/changeset/base/295226

Log:
  Fix build.

Modified:
  head/lib/libmemstat/memstat_uma.c

Modified: head/lib/libmemstat/memstat_uma.c
==
--- head/lib/libmemstat/memstat_uma.c   Wed Feb  3 23:41:58 2016
(r295225)
+++ head/lib/libmemstat/memstat_uma.c   Thu Feb  4 00:23:21 2016
(r295226)
@@ -29,6 +29,7 @@
 #include 
 #include 
 #include 
+#include 
 
 #include 
 #include 
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


svn commit: r295230 - head/share/mk

2016-02-03 Thread Bryan Drewery
Author: bdrewery
Date: Thu Feb  4 01:08:51 2016
New Revision: 295230
URL: https://svnweb.freebsd.org/changeset/base/295230

Log:
  Fix style and remove excess / for installing SYMLINKS.
  
  Sponsored by: EMC / Isilon Storage Division

Modified:
  head/share/mk/bsd.incs.mk
  head/share/mk/bsd.links.mk

Modified: head/share/mk/bsd.incs.mk
==
--- head/share/mk/bsd.incs.mk   Thu Feb  4 01:08:48 2016(r295229)
+++ head/share/mk/bsd.incs.mk   Thu Feb  4 01:08:51 2016(r295230)
@@ -80,7 +80,7 @@ _${group}INS: ${_${group}INCS}
 .if defined(INCSLINKS) && !empty(INCSLINKS)
 installincludes:
 .for s t in ${INCSLINKS}
-   ${INSTALL_SYMLINK} $s ${DESTDIR}$t
+   ${INSTALL_SYMLINK} ${s} ${DESTDIR}${t}
 .endfor
 .endif
 .endif # !target(installincludes)

Modified: head/share/mk/bsd.links.mk
==
--- head/share/mk/bsd.links.mk  Thu Feb  4 01:08:48 2016(r295229)
+++ head/share/mk/bsd.links.mk  Thu Feb  4 01:08:51 2016(r295230)
@@ -8,8 +8,8 @@ afterinstall: _installlinks
 .ORDER: realinstall _installlinks
 _installlinks:
 .for s t in ${LINKS}
-   ${INSTALL_LINK} ${DESTDIR}$s ${DESTDIR}$t
+   ${INSTALL_LINK} ${DESTDIR}${s} ${DESTDIR}${t}
 .endfor
 .for s t in ${SYMLINKS}
-   ${INSTALL_SYMLINK} $s ${DESTDIR}/$t
+   ${INSTALL_SYMLINK} ${s} ${DESTDIR}${t}
 .endfor
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


svn commit: r295228 - head/share/mk

2016-02-03 Thread Bryan Drewery
Author: bdrewery
Date: Thu Feb  4 01:08:45 2016
New Revision: 295228
URL: https://svnweb.freebsd.org/changeset/base/295228

Log:
  Fix cat files being installed to wrong place since r284685.
  
  Sponsored by: EMC / Isilon Storage Division

Modified:
  head/share/mk/bsd.man.mk

Modified: head/share/mk/bsd.man.mk
==
--- head/share/mk/bsd.man.mkThu Feb  4 01:08:42 2016(r295227)
+++ head/share/mk/bsd.man.mkThu Feb  4 01:08:45 2016(r295228)
@@ -226,8 +226,8 @@ _maninstall: ${MAN}
 .endfor
 .if defined(MANBUILDCAT) && !empty(MANBUILDCAT)
 .for _oname _osect _dname _dsect in ${MLINKS:C/\.([^.]*)$/.\1 \1/}
-   @l=${DESTDIR}${MANDIR}${_osect}${MANSUBDIR}/${_oname}; \
-   t=${DESTDIR}${MANDIR}${_dsect}${MANSUBDIR}/${_dname}; \
+   @l=${DESTDIR}${CATDIR}${_osect}${MANSUBDIR}/${_oname}; \
+   t=${DESTDIR}${CATDIR}${_dsect}${MANSUBDIR}/${_dname}; \
${ECHO} $${t}${ZEXT} -\> $${l}${ZEXT}; \
rm -f $${t} $${t}${MCOMPRESS_EXT}; \
${INSTALL_LINK} $${l}${ZEXT} $${t}${ZEXT}
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


svn commit: r295229 - head/share/mk

2016-02-03 Thread Bryan Drewery
Author: bdrewery
Date: Thu Feb  4 01:08:48 2016
New Revision: 295229
URL: https://svnweb.freebsd.org/changeset/base/295229

Log:
  MLINKS: Deduplicate some of the logic, simplify, and unhide install commands.
  
  Sponsored by: EMC / Isilon Storage Division

Modified:
  head/share/mk/bsd.man.mk

Modified: head/share/mk/bsd.man.mk
==
--- head/share/mk/bsd.man.mkThu Feb  4 01:08:45 2016(r295228)
+++ head/share/mk/bsd.man.mkThu Feb  4 01:08:48 2016(r295229)
@@ -171,6 +171,17 @@ ${__target}: ${__page}
 
 .endif # ${MK_MANCOMPRESS} == "no"
 
+.if !defined(NO_MLINKS) && defined(MLINKS) && !empty(MLINKS)
+.for _oname _osect _dname _dsect in ${MLINKS:C/\.([^.]*)$/.\1 \1/}
+_MANLINKS+=${MANDIR}${_osect}${MANSUBDIR}/${_oname} \
+   ${MANDIR}${_dsect}${MANSUBDIR}/${_dname}
+.if defined(MANBUILDCAT) && !empty(MANBUILDCAT)
+_MANLINKS+=${CATDIR}${_osect}${MANSUBDIR}/${_oname} \
+   ${CATDIR}${_dsect}${MANSUBDIR}/${_dname}
+.endif
+.endfor
+.endif
+
 maninstall: _maninstall
 _maninstall:
 .if defined(MAN) && !empty(MAN)
@@ -215,25 +226,10 @@ _maninstall: ${MAN}
 .endfor
 .endif # ${MK_MANCOMPRESS} == "no"
 .endif
-
-.if !defined(NO_MLINKS) && defined(MLINKS) && !empty(MLINKS)
-.for _oname _osect _dname _dsect in ${MLINKS:C/\.([^.]*)$/.\1 \1/}
-   @l=${DESTDIR}${MANDIR}${_osect}${MANSUBDIR}/${_oname}; \
-   t=${DESTDIR}${MANDIR}${_dsect}${MANSUBDIR}/${_dname}; \
-   ${ECHO} $${t}${ZEXT} -\> $${l}${ZEXT}; \
-   rm -f $${t} $${t}${MCOMPRESS_EXT}; \
-   ${INSTALL_LINK} $${l}${ZEXT} $${t}${ZEXT}
+.for l t in ${_MANLINKS}
+   rm -f ${DESTDIR}${t} ${DESTDIR}${t}${MCOMPRESS_EXT}; \
+   ${INSTALL_LINK} ${DESTDIR}${l}${ZEXT} ${DESTDIR}${t}${ZEXT}
 .endfor
-.if defined(MANBUILDCAT) && !empty(MANBUILDCAT)
-.for _oname _osect _dname _dsect in ${MLINKS:C/\.([^.]*)$/.\1 \1/}
-   @l=${DESTDIR}${CATDIR}${_osect}${MANSUBDIR}/${_oname}; \
-   t=${DESTDIR}${CATDIR}${_dsect}${MANSUBDIR}/${_dname}; \
-   ${ECHO} $${t}${ZEXT} -\> $${l}${ZEXT}; \
-   rm -f $${t} $${t}${MCOMPRESS_EXT}; \
-   ${INSTALL_LINK} $${l}${ZEXT} $${t}${ZEXT}
-.endfor
-.endif
-.endif
 
 manlint:
 .if defined(MAN) && !empty(MAN)
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


svn commit: r295227 - head/share/mk

2016-02-03 Thread Bryan Drewery
Author: bdrewery
Date: Thu Feb  4 01:08:42 2016
New Revision: 295227
URL: https://svnweb.freebsd.org/changeset/base/295227

Log:
  Stop hiding link install commands.
  
  This is no longer needed now that a .for loop is used rather
  than inline shell script.
  
  Sponsored by: EMC / Isilon Storage Division

Modified:
  head/share/mk/bsd.incs.mk
  head/share/mk/bsd.links.mk

Modified: head/share/mk/bsd.incs.mk
==
--- head/share/mk/bsd.incs.mk   Thu Feb  4 00:23:21 2016(r295226)
+++ head/share/mk/bsd.incs.mk   Thu Feb  4 01:08:42 2016(r295227)
@@ -80,7 +80,6 @@ _${group}INS: ${_${group}INCS}
 .if defined(INCSLINKS) && !empty(INCSLINKS)
 installincludes:
 .for s t in ${INCSLINKS}
-   @${ECHO} "$t -> $s" ; \
${INSTALL_SYMLINK} $s ${DESTDIR}$t
 .endfor
 .endif

Modified: head/share/mk/bsd.links.mk
==
--- head/share/mk/bsd.links.mk  Thu Feb  4 00:23:21 2016(r295226)
+++ head/share/mk/bsd.links.mk  Thu Feb  4 01:08:42 2016(r295227)
@@ -8,10 +8,8 @@ afterinstall: _installlinks
 .ORDER: realinstall _installlinks
 _installlinks:
 .for s t in ${LINKS}
-   @${ECHO} "$t -> $s" ;\
${INSTALL_LINK} ${DESTDIR}$s ${DESTDIR}$t
 .endfor
 .for s t in ${SYMLINKS}
-   @${ECHO} "$t -> $s" ;\
${INSTALL_SYMLINK} $s ${DESTDIR}/$t
 .endfor
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


Re: svn commit: r295224 - head/bin/csh

2016-02-03 Thread Hajimu UMEMOTO
Hi,

> On Wed, 3 Feb 2016 23:37:25 + (UTC)
> Bryan Drewery  said:

bdrewery> Author: bdrewery
bdrewery> Date: Wed Feb  3 23:37:24 2016
bdrewery> New Revision: 295224
bdrewery> URL: https://svnweb.freebsd.org/changeset/base/295224

bdrewery> Log:
bdrewery>   Don't link /usr/share/nls/de_DE.UTF-8/tcsh.cat to itself.

Oops, it's my fault.  Thank you!

--
Hajimu UMEMOTO
u...@mahoroba.org  u...@freebsd.org
http://www.mahoroba.org/~ume/
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


svn commit: r295214 - head/sys/arm64/arm64

2016-02-03 Thread Andrew Turner
Author: andrew
Date: Wed Feb  3 17:00:19 2016
New Revision: 295214
URL: https://svnweb.freebsd.org/changeset/base/295214

Log:
  Handle a misaligned stack pointer exception from userspace. The exception
  still needs to be enabled, but this will help with testing.
  
  Sponsored by: ABT Systems Ltd

Modified:
  head/sys/arm64/arm64/trap.c

Modified: head/sys/arm64/arm64/trap.c
==
--- head/sys/arm64/arm64/trap.c Wed Feb  3 16:44:06 2016(r295213)
+++ head/sys/arm64/arm64/trap.c Wed Feb  3 17:00:19 2016(r295214)
@@ -374,6 +374,10 @@ do_el0_sync(struct trapframe *frame)
case EXCP_UNKNOWN:
el0_excp_unknown(frame);
break;
+   case EXCP_SP_ALIGN:
+   call_trapsignal(td, SIGBUS, BUS_ADRALN, (void *)frame->tf_sp);
+   userret(td, frame);
+   break;
case EXCP_PC_ALIGN:
call_trapsignal(td, SIGBUS, BUS_ADRALN, (void *)frame->tf_elr);
userret(td, frame);
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


svn commit: r295212 - head/usr.sbin/ctld

2016-02-03 Thread Jakub Wojciech Klama
Author: jceel
Date: Wed Feb  3 15:45:13 2016
New Revision: 295212
URL: https://svnweb.freebsd.org/changeset/base/295212

Log:
  Add an additional, libucl-based configuration file parser to ctld.
  
  Default ctld behavior remains unchanged - libucl parser can be selected
  explicitly by adding -u switch to ctld command line.
  
  Reviewed by:  trasz
  Approved by:  trasz (mentor)
  MFC after:1 month
  Relnotes: yes
  Sponsored by: iXsystems, Inc.
  Differential Revision:https://reviews.freebsd.org/D4534

Added:
  head/usr.sbin/ctld/uclparse.c   (contents, props changed)
Modified:
  head/usr.sbin/ctld/Makefile
  head/usr.sbin/ctld/ctld.c
  head/usr.sbin/ctld/ctld.h
  head/usr.sbin/ctld/parse.y

Modified: head/usr.sbin/ctld/Makefile
==
--- head/usr.sbin/ctld/Makefile Wed Feb  3 15:16:20 2016(r295211)
+++ head/usr.sbin/ctld/Makefile Wed Feb  3 15:45:13 2016(r295212)
@@ -1,8 +1,11 @@
 # $FreeBSD$
 
+CFLAGS+=-I${.CURDIR}/../../contrib/libucl/include
+.PATH:  ${.CURDIR}/../../contrib/libucl/include
+
 PROG=  ctld
 SRCS=  chap.c ctld.c discovery.c isns.c kernel.c keys.c log.c
-SRCS+= login.c parse.y pdu.c token.l y.tab.h
+SRCS+= login.c parse.y pdu.c token.l y.tab.h uclparse.c
 CFLAGS+=   -I${.CURDIR}
 CFLAGS+=   -I${.CURDIR}/../../sys
 CFLAGS+=   -I${.CURDIR}/../../sys/cam/ctl
@@ -10,7 +13,7 @@ CFLAGS+=  -I${.CURDIR}/../../sys/dev/iscs
 #CFLAGS+=  -DICL_KERNEL_PROXY
 MAN=   ctld.8 ctl.conf.5
 
-LIBADD=bsdxml l md sbuf util
+LIBADD=bsdxml l md sbuf util ucl m
 
 YFLAGS+=   -v
 CLEANFILES=y.tab.c y.tab.h y.output

Modified: head/usr.sbin/ctld/ctld.c
==
--- head/usr.sbin/ctld/ctld.c   Wed Feb  3 15:16:20 2016(r295211)
+++ head/usr.sbin/ctld/ctld.c   Wed Feb  3 15:45:13 2016(r295212)
@@ -34,6 +34,7 @@ __FBSDID("$FreeBSD$");
 #include 
 #include 
 #include 
+#include 
 #include 
 #include 
 #include 
@@ -2491,6 +2492,104 @@ register_signals(void)
log_err(1, "sigaction");
 }
 
+static void
+check_perms(const char *path)
+{
+   struct stat sb;
+   int error;
+
+   error = stat(path, );
+   if (error != 0) {
+   log_warn("stat");
+   return;
+   }
+   if (sb.st_mode & S_IWOTH) {
+   log_warnx("%s is world-writable", path);
+   } else if (sb.st_mode & S_IROTH) {
+   log_warnx("%s is world-readable", path);
+   } else if (sb.st_mode & S_IXOTH) {
+   /*
+* Ok, this one doesn't matter, but still do it,
+* just for consistency.
+*/
+   log_warnx("%s is world-executable", path);
+   }
+
+   /*
+* XXX: Should we also check for owner != 0?
+*/
+}
+
+static struct conf *
+conf_new_from_file(const char *path, struct conf *oldconf, bool ucl)
+{
+   struct conf *conf;
+   struct auth_group *ag;
+   struct portal_group *pg;
+   struct pport *pp;
+   int error;
+
+   log_debugx("obtaining configuration from %s", path);
+
+   conf = conf_new();
+
+   TAILQ_FOREACH(pp, >conf_pports, pp_next)
+   pport_copy(pp, conf);
+
+   ag = auth_group_new(conf, "default");
+   assert(ag != NULL);
+
+   ag = auth_group_new(conf, "no-authentication");
+   assert(ag != NULL);
+   ag->ag_type = AG_TYPE_NO_AUTHENTICATION;
+
+   ag = auth_group_new(conf, "no-access");
+   assert(ag != NULL);
+   ag->ag_type = AG_TYPE_DENY;
+
+   pg = portal_group_new(conf, "default");
+   assert(pg != NULL);
+
+   if (ucl)
+   error = uclparse_conf(conf, path);
+   else
+   error = parse_conf(conf, path);
+
+   if (error != 0) {
+   conf_delete(conf);
+   return (NULL);
+   }
+
+   check_perms(path);
+
+   if (conf->conf_default_ag_defined == false) {
+   log_debugx("auth-group \"default\" not defined; "
+   "going with defaults");
+   ag = auth_group_find(conf, "default");
+   assert(ag != NULL);
+   ag->ag_type = AG_TYPE_DENY;
+   }
+
+   if (conf->conf_default_pg_defined == false) {
+   log_debugx("portal-group \"default\" not defined; "
+   "going with defaults");
+   pg = portal_group_find(conf, "default");
+   assert(pg != NULL);
+   portal_group_add_listen(pg, "0.0.0.0:3260", false);
+   portal_group_add_listen(pg, "[::]:3260", false);
+   }
+
+   conf->conf_kernel_port_on = true;
+
+   error = conf_verify(conf);
+   if (error != 0) {
+   conf_delete(conf);
+   return (NULL);
+   }
+
+   return (conf);
+}
+
 int
 main(int argc, char 

svn commit: r295213 - in head/sys/arm: arm at91 cavium/cns11xx include xscale/i8134x xscale/ixp425 xscale/pxa

2016-02-03 Thread Michal Meloun
Author: mmel
Date: Wed Feb  3 16:44:06 2016
New Revision: 295213
URL: https://svnweb.freebsd.org/changeset/base/295213

Log:
  ARM: Consistently use cpu_setttb() instead of setttb().
  Remove unused #define for drain_writebuf.

Modified:
  head/sys/arm/arm/machdep.c
  head/sys/arm/at91/at91_machdep.c
  head/sys/arm/cavium/cns11xx/econa_machdep.c
  head/sys/arm/include/cpufunc.h
  head/sys/arm/xscale/i8134x/crb_machdep.c
  head/sys/arm/xscale/ixp425/avila_machdep.c
  head/sys/arm/xscale/pxa/pxa_machdep.c

Modified: head/sys/arm/arm/machdep.c
==
--- head/sys/arm/arm/genassym.c Thu Feb  4 05:03:35 2016(r295234)
+++ head/sys/arm/arm/genassym.c Thu Feb  4 06:39:20 2016(r295235)
@@ -59,7 +59,6 @@ __FBSDID("$FreeBSD$");
 #include 
 
 ASSYM(KERNBASE, KERNBASE);
-ASSYM(PCB_NOALIGNFLT, PCB_NOALIGNFLT);
 #if __ARM_ARCH >= 6
 ASSYM(CPU_ASID_KERNEL,CPU_ASID_KERNEL);
 #endif
@@ -67,7 +66,6 @@ ASSYM(PCB_ONFAULT, offsetof(struct pcb, 
 #if __ARM_ARCH < 6
 ASSYM(PCB_DACR, offsetof(struct pcb, pcb_dacr));
 #endif
-ASSYM(PCB_FLAGS, offsetof(struct pcb, pcb_flags));
 ASSYM(PCB_PAGEDIR, offsetof(struct pcb, pcb_pagedir));
 #if __ARM_ARCH < 6
 ASSYM(PCB_L1VEC, offsetof(struct pcb, pcb_l1vec));
@@ -93,23 +91,15 @@ ASSYM(M_DATA, offsetof(struct mbuf, m_da
 ASSYM(M_NEXT, offsetof(struct mbuf, m_next));
 ASSYM(IP_SRC, offsetof(struct ip, ip_src));
 ASSYM(IP_DST, offsetof(struct ip, ip_dst));
-ASSYM(CF_SETTTB, offsetof(struct cpu_functions, cf_setttb));
-ASSYM(CF_CONTROL, offsetof(struct cpu_functions, cf_control));
 ASSYM(CF_CONTEXT_SWITCH, offsetof(struct cpu_functions, cf_context_switch));
 ASSYM(CF_DCACHE_WB_RANGE, offsetof(struct cpu_functions, cf_dcache_wb_range));
-ASSYM(CF_L2CACHE_WB_RANGE, offsetof(struct cpu_functions, 
cf_l2cache_wb_range));
 ASSYM(CF_IDCACHE_WBINV_ALL, offsetof(struct cpu_functions, 
cf_idcache_wbinv_all));
 ASSYM(CF_L2CACHE_WBINV_ALL, offsetof(struct cpu_functions, 
cf_l2cache_wbinv_all));
 ASSYM(CF_TLB_FLUSHID_SE, offsetof(struct cpu_functions, cf_tlb_flushID_SE));
 
-ASSYM(V_TRAP, offsetof(struct vmmeter, v_trap));
-ASSYM(V_SOFT, offsetof(struct vmmeter, v_soft));
-ASSYM(V_INTR, offsetof(struct vmmeter, v_intr));
-
 ASSYM(TD_PCB, offsetof(struct thread, td_pcb));
 ASSYM(TD_FLAGS, offsetof(struct thread, td_flags));
 ASSYM(TD_PROC, offsetof(struct thread, td_proc));
-ASSYM(TD_FRAME, offsetof(struct thread, td_frame));
 ASSYM(TD_MD, offsetof(struct thread, td_md));
 ASSYM(TD_LOCK, offsetof(struct thread, td_lock));
 ASSYM(MD_TP, offsetof(struct mdthread, md_tp));
@@ -146,10 +136,6 @@ ASSYM(PMAP_INCLUDE_PTE_SYNC, 1);
 #endif
 ASSYM(TDF_ASTPENDING, TDF_ASTPENDING);
 ASSYM(TDF_NEEDRESCHED, TDF_NEEDRESCHED);
-ASSYM(P_TRACED, P_TRACED);
-ASSYM(P_SIGEVENT, P_SIGEVENT);
-ASSYM(P_PROFIL, P_PROFIL);
-ASSYM(TRAPFRAMESIZE, sizeof(struct trapframe));
 
 ASSYM(MAXCOMLEN, MAXCOMLEN);
 ASSYM(MAXCPU, MAXCPU);
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


svn commit: r295233 - in head/sys: compat/cloudabi kern sys

2016-02-03 Thread Mateusz Guzik
Author: mjg
Date: Thu Feb  4 04:25:30 2016
New Revision: 295233
URL: https://svnweb.freebsd.org/changeset/base/295233

Log:
  fork: plug a use after free of the returned process
  
  fork1 required its callers to pass a pointer to struct proc * which would
  be set to the new process (if any). procdesc and racct manipulation also
  used said pointer.
  
  However, the process could have exited prior to do_fork return and be
  automatically reaped, thus making this a use-after-free.
  
  Fix the problem by letting callers indicate whether they want the pid or
  the struct proc, return the process in stopped state for the latter case.
  
  Reviewed by:  kib

Modified:
  head/sys/compat/cloudabi/cloudabi_proc.c
  head/sys/kern/kern_fork.c
  head/sys/kern/kern_racct.c
  head/sys/sys/proc.h

Modified: head/sys/compat/cloudabi/cloudabi_proc.c
==
--- head/sys/compat/cloudabi/cloudabi_proc.cThu Feb  4 04:22:18 2016
(r295232)
+++ head/sys/compat/cloudabi/cloudabi_proc.cThu Feb  4 04:25:30 2016
(r295233)
@@ -77,13 +77,11 @@ cloudabi_sys_proc_fork(struct thread *td
 {
struct fork_req fr;
struct filecaps fcaps = {};
-   struct proc *p2;
int error, fd;
 
cap_rights_init(_rights, CAP_FSTAT, CAP_EVENT);
bzero(, sizeof(fr));
fr.fr_flags = RFFDG | RFPROC | RFPROCDESC;
-   fr.fr_procp = 
fr.fr_pd_fd = 
fr.fr_pd_fcaps = 
error = fork1(td, );

Modified: head/sys/kern/kern_fork.c
==
--- head/sys/kern/kern_fork.c   Thu Feb  4 04:22:18 2016(r295232)
+++ head/sys/kern/kern_fork.c   Thu Feb  4 04:25:30 2016(r295233)
@@ -102,15 +102,14 @@ int
 sys_fork(struct thread *td, struct fork_args *uap)
 {
struct fork_req fr;
-   int error;
-   struct proc *p2;
+   int error, pid;
 
bzero(, sizeof(fr));
fr.fr_flags = RFFDG | RFPROC;
-   fr.fr_procp = 
+   fr.fr_pidp = 
error = fork1(td, );
if (error == 0) {
-   td->td_retval[0] = p2->p_pid;
+   td->td_retval[0] = pid;
td->td_retval[1] = 0;
}
return (error);
@@ -123,12 +122,11 @@ sys_pdfork(td, uap)
struct pdfork_args *uap;
 {
struct fork_req fr;
-   int error, fd;
-   struct proc *p2;
+   int error, fd, pid;
 
bzero(, sizeof(fr));
fr.fr_flags = RFFDG | RFPROC | RFPROCDESC;
-   fr.fr_procp = 
+   fr.fr_pidp = 
fr.fr_pd_fd = 
fr.fr_pd_flags = uap->flags;
/*
@@ -138,7 +136,7 @@ sys_pdfork(td, uap)
 */
error = fork1(td, );
if (error == 0) {
-   td->td_retval[0] = p2->p_pid;
+   td->td_retval[0] = pid;
td->td_retval[1] = 0;
error = copyout(, uap->fdp, sizeof(fd));
}
@@ -150,15 +148,14 @@ int
 sys_vfork(struct thread *td, struct vfork_args *uap)
 {
struct fork_req fr;
-   int error;
-   struct proc *p2;
+   int error, pid;
 
bzero(, sizeof(fr));
fr.fr_flags = RFFDG | RFPROC | RFPPWAIT | RFMEM;
-   fr.fr_procp = 
+   fr.fr_pidp = 
error = fork1(td, );
if (error == 0) {
-   td->td_retval[0] = p2->p_pid;
+   td->td_retval[0] = pid;
td->td_retval[1] = 0;
}
return (error);
@@ -168,8 +165,7 @@ int
 sys_rfork(struct thread *td, struct rfork_args *uap)
 {
struct fork_req fr;
-   struct proc *p2;
-   int error;
+   int error, pid;
 
/* Don't allow kernel-only flags. */
if ((uap->flags & RFKERNELONLY) != 0)
@@ -178,10 +174,10 @@ sys_rfork(struct thread *td, struct rfor
AUDIT_ARG_FFLAGS(uap->flags);
bzero(, sizeof(fr));
fr.fr_flags = uap->flags;
-   fr.fr_procp = 
+   fr.fr_pidp = 
error = fork1(td, );
if (error == 0) {
-   td->td_retval[0] = p2 ? p2->p_pid : 0;
+   td->td_retval[0] = pid;
td->td_retval[1] = 0;
}
return (error);
@@ -382,11 +378,11 @@ fail:
 }
 
 static void
-do_fork(struct thread *td, int flags, struct proc *p2, struct thread *td2,
-struct vmspace *vm2, int pdflags)
+do_fork(struct thread *td, struct fork_req *fr, struct proc *p2, struct thread 
*td2,
+struct vmspace *vm2, struct file *fp_procdesc)
 {
struct proc *p1, *pptr;
-   int p2_held, trypid;
+   int trypid;
struct filedesc *fd;
struct filedesc_to_leader *fdtol;
struct sigacts *newsigacts;
@@ -394,10 +390,9 @@ do_fork(struct thread *td, int flags, st
sx_assert(_lock, SX_SLOCKED);
sx_assert(_lock, SX_XLOCKED);
 
-   p2_held = 0;
p1 = td->td_proc;
 
-   trypid = fork_findpid(flags);
+   trypid = fork_findpid(fr->fr_flags);
 
sx_sunlock(_lock);
 
@@ 

svn commit: r295231 - in head/sys: arm64/arm64 mips/mips powerpc/powerpc riscv/riscv

2016-02-03 Thread Gleb Smirnoff
Author: glebius
Date: Thu Feb  4 03:55:41 2016
New Revision: 295231
URL: https://svnweb.freebsd.org/changeset/base/295231

Log:
  Fix build.

Modified:
  head/sys/arm64/arm64/uma_machdep.c
  head/sys/mips/mips/uma_machdep.c
  head/sys/powerpc/powerpc/uma_machdep.c
  head/sys/riscv/riscv/uma_machdep.c

Modified: head/sys/arm64/arm64/uma_machdep.c
==
--- head/sys/arm64/arm64/uma_machdep.c  Thu Feb  4 01:08:51 2016
(r295230)
+++ head/sys/arm64/arm64/uma_machdep.c  Thu Feb  4 03:55:41 2016
(r295231)
@@ -32,6 +32,7 @@ __FBSDID("$FreeBSD$");
 #include 
 #include 
 #include 
+#include 
 #include 
 #include 
 #include 

Modified: head/sys/mips/mips/uma_machdep.c
==
--- head/sys/mips/mips/uma_machdep.cThu Feb  4 01:08:51 2016
(r295230)
+++ head/sys/mips/mips/uma_machdep.cThu Feb  4 03:55:41 2016
(r295231)
@@ -32,6 +32,7 @@ __FBSDID("$FreeBSD$");
 #include 
 #include 
 #include 
+#include 
 #include 
 #include 
 #include 

Modified: head/sys/powerpc/powerpc/uma_machdep.c
==
--- head/sys/powerpc/powerpc/uma_machdep.c  Thu Feb  4 01:08:51 2016
(r295230)
+++ head/sys/powerpc/powerpc/uma_machdep.c  Thu Feb  4 03:55:41 2016
(r295231)
@@ -34,6 +34,7 @@ __FBSDID("$FreeBSD$");
 #include 
 #include 
 #include 
+#include 
 #include 
 #include 
 #include 

Modified: head/sys/riscv/riscv/uma_machdep.c
==
--- head/sys/riscv/riscv/uma_machdep.c  Thu Feb  4 01:08:51 2016
(r295230)
+++ head/sys/riscv/riscv/uma_machdep.c  Thu Feb  4 03:55:41 2016
(r295231)
@@ -32,6 +32,7 @@ __FBSDID("$FreeBSD$");
 #include 
 #include 
 #include 
+#include 
 #include 
 #include 
 #include 
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


svn commit: r295232 - in head/sys: compat/cloudabi compat/linux kern sys

2016-02-03 Thread Mateusz Guzik
Author: mjg
Date: Thu Feb  4 04:22:18 2016
New Revision: 295232
URL: https://svnweb.freebsd.org/changeset/base/295232

Log:
  fork: pass arguments to fork1 in a dedicated structure
  
  Suggested by: kib

Modified:
  head/sys/compat/cloudabi/cloudabi_proc.c
  head/sys/compat/linux/linux_fork.c
  head/sys/kern/init_main.c
  head/sys/kern/kern_fork.c
  head/sys/kern/kern_kthread.c
  head/sys/sys/proc.h

Modified: head/sys/compat/cloudabi/cloudabi_proc.c
==
--- head/sys/compat/cloudabi/cloudabi_proc.cThu Feb  4 03:55:41 2016
(r295231)
+++ head/sys/compat/cloudabi/cloudabi_proc.cThu Feb  4 04:22:18 2016
(r295232)
@@ -75,12 +75,18 @@ int
 cloudabi_sys_proc_fork(struct thread *td,
 struct cloudabi_sys_proc_fork_args *uap)
 {
+   struct fork_req fr;
struct filecaps fcaps = {};
struct proc *p2;
int error, fd;
 
cap_rights_init(_rights, CAP_FSTAT, CAP_EVENT);
-   error = fork1(td, RFFDG | RFPROC | RFPROCDESC, 0, , , 0, );
+   bzero(, sizeof(fr));
+   fr.fr_flags = RFFDG | RFPROC | RFPROCDESC;
+   fr.fr_procp = 
+   fr.fr_pd_fd = 
+   fr.fr_pd_fcaps = 
+   error = fork1(td, );
if (error != 0)
return (error);
/* Return the file descriptor to the parent process. */

Modified: head/sys/compat/linux/linux_fork.c
==
--- head/sys/compat/linux/linux_fork.c  Thu Feb  4 03:55:41 2016
(r295231)
+++ head/sys/compat/linux/linux_fork.c  Thu Feb  4 04:22:18 2016
(r295232)
@@ -64,6 +64,7 @@ __FBSDID("$FreeBSD$");
 int
 linux_fork(struct thread *td, struct linux_fork_args *args)
 {
+   struct fork_req fr;
int error;
struct proc *p2;
struct thread *td2;
@@ -73,8 +74,10 @@ linux_fork(struct thread *td, struct lin
printf(ARGS(fork, ""));
 #endif
 
-   if ((error = fork1(td, RFFDG | RFPROC | RFSTOPPED, 0, , NULL, 0,
-   NULL)) != 0)
+   bzero(, sizeof(fr));
+   fr.fr_flags = RFFDG | RFPROC | RFSTOPPED;
+   fr.fr_procp = 
+   if ((error = fork1(td, )) != 0)
return (error);
 
td2 = FIRST_THREAD_IN_PROC(p2);
@@ -97,6 +100,7 @@ linux_fork(struct thread *td, struct lin
 int
 linux_vfork(struct thread *td, struct linux_vfork_args *args)
 {
+   struct fork_req fr;
int error;
struct proc *p2;
struct thread *td2;
@@ -106,8 +110,10 @@ linux_vfork(struct thread *td, struct li
printf(ARGS(vfork, ""));
 #endif
 
-   if ((error = fork1(td, RFFDG | RFPROC | RFMEM | RFPPWAIT | RFSTOPPED,
-   0, , NULL, 0, NULL)) != 0)
+   bzero(, sizeof(fr));
+   fr.fr_flags = RFFDG | RFPROC | RFMEM | RFPPWAIT | RFSTOPPED;
+   fr.fr_procp = 
+   if ((error = fork1(td, )) != 0)
return (error);
 
td2 = FIRST_THREAD_IN_PROC(p2);
@@ -130,6 +136,7 @@ linux_vfork(struct thread *td, struct li
 static int
 linux_clone_proc(struct thread *td, struct linux_clone_args *args)
 {
+   struct fork_req fr;
int error, ff = RFPROC | RFSTOPPED;
struct proc *p2;
struct thread *td2;
@@ -170,7 +177,10 @@ linux_clone_proc(struct thread *td, stru
if (args->flags & LINUX_CLONE_VFORK)
ff |= RFPPWAIT;
 
-   error = fork1(td, ff, 0, , NULL, 0, NULL);
+   bzero(, sizeof(fr));
+   fr.fr_flags = ff;
+   fr.fr_procp = 
+   error = fork1(td, );
if (error)
return (error);
 

Modified: head/sys/kern/init_main.c
==
--- head/sys/kern/init_main.c   Thu Feb  4 03:55:41 2016(r295231)
+++ head/sys/kern/init_main.c   Thu Feb  4 04:22:18 2016(r295232)
@@ -828,12 +828,15 @@ start_init(void *dummy)
 static void
 create_init(const void *udata __unused)
 {
+   struct fork_req fr;
struct ucred *newcred, *oldcred;
struct thread *td;
int error;
 
-   error = fork1(, RFFDG | RFPROC | RFSTOPPED, 0, ,
-   NULL, 0, NULL);
+   bzero(, sizeof(fr));
+   fr.fr_flags = RFFDG | RFPROC | RFSTOPPED;
+   fr.fr_procp = 
+   error = fork1(, );
if (error)
panic("cannot fork init: %d\n", error);
KASSERT(initproc->p_pid == 1, ("create_init: initproc->p_pid != 1"));

Modified: head/sys/kern/kern_fork.c
==
--- head/sys/kern/kern_fork.c   Thu Feb  4 03:55:41 2016(r295231)
+++ head/sys/kern/kern_fork.c   Thu Feb  4 04:22:18 2016(r295232)
@@ -101,10 +101,14 @@ struct fork_args {
 int
 sys_fork(struct thread *td, struct fork_args *uap)
 {
+   struct fork_req fr;
int error;
struct proc *p2;
 
-   error = fork1(td, RFFDG | RFPROC, 0, , NULL, 0, NULL);
+   bzero(, sizeof(fr));
+  

svn commit: r295234 - head/share/i18n/esdb/MISC

2016-02-03 Thread Hajimu UMEMOTO
Author: ume
Date: Thu Feb  4 05:03:35 2016
New Revision: 295234
URL: https://svnweb.freebsd.org/changeset/base/295234

Log:
  Make sure to enable aliases for SHIFT_JIS.
  
  MFC after:3 days

Modified:
  head/share/i18n/esdb/MISC/MISC.alias

Modified: head/share/i18n/esdb/MISC/MISC.alias
==
--- head/share/i18n/esdb/MISC/MISC.aliasThu Feb  4 04:25:30 2016
(r295233)
+++ head/share/i18n/esdb/MISC/MISC.aliasThu Feb  4 05:03:35 2016
(r295234)
@@ -29,10 +29,10 @@ JISX0208:1990   x0208
 
 JOHAB  cp1361
 
-SHIFT_JIS  csshiftjis
-SHIFT_JIS  ms_kanji
-SHIFT_JIS  sjis
+Shift_JIS  csshiftjis
+Shift_JIS  ms_kanji
+Shift_JIS  sjis
 
-SHIFT_JIS-2004 shift_jisx0213
+Shift_JIS-2004 shift_jisx0213
 
 TDS565 iso-ir-230
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"


Re: svn commit: r295209 - head/sys/fs/ext2fs

2016-02-03 Thread Pedro Giffuni



On 02/03/16 12:38, Conrad Meyer wrote:

On Wed, Feb 3, 2016 at 6:31 AM, Pedro F. Giffuni  wrote:

Author: pfg
Date: Wed Feb  3 14:31:23 2016
New Revision: 295209
URL: https://svnweb.freebsd.org/changeset/base/295209

Log:
   Revert r294695:
   ext2fs: passthrough any extra timestamps to the dinode struct.

   While it passed the classic testing, the change appears to have
   caused some regression and still requires some more precautions.

   PR:   206820


What's the classic testing — xfstests or something more/less thorough?



My regular testing is fsx and then build a port (cad/spice) on it.
Other people have been running other tests like pho's testsuite so
we usually catch anything.



I was going to ask what the regression was, but then I noticed the PR number.



Yeah, the error is related to the inode size: I only tested the
default (256) which has no problems. Considering the upcoming release
I just want to get the get this reverted and I'll worry about a real
fix later.


Pedro.
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"

Re: svn commit: r292206 - in head/contrib/unbound: . compat daemon dns64 dnstap doc iterator libunbound libunbound/python libunbound/python/doc libunbound/python/doc/modules libunbound/python/examples

2016-02-03 Thread Peter Wemm
On Monday, December 14, 2015 01:01:51 PM Dag-Erling Smørgrav wrote:
> Author: des
> Date: Mon Dec 14 13:01:51 2015
> New Revision: 292206
> URL: https://svnweb.freebsd.org/changeset/base/292206
> 
> Log:
>   Upgrade to Unbound 1.5.7.
> 
> Added:
>   head/contrib/unbound/.gitignore
>  - copied unchanged from r292133, vendor/unbound/dist/.gitignore
>   head/contrib/unbound/compat/isblank.c
>  - copied unchanged from r292133, vendor/unbound/dist/compat/isblank.c
> Modified:
>   head/contrib/unbound/Makefile.in

An error was introduced here that breaks some of the support scripts:

@@ -107,16 +107,15 @@
 fi
 
 # create self-signed cert for server
-cat >request.cfg < request.cfg
+echo "default_bits=$BITS\n" >> request.cfg
+echo "default_md=$HASH\n" >> request.cfg
+echo "prompt=no\n" >> request.cfg
+echo "distinguished_name=req_distinguished_name\n" >> request.cfg
+echo "\n" >> request.cfg
+echo "[req_distinguished_name]\n" >> request.cfg
+echo "commonName=$SERVERNAME\n" >> request.cfg
 
-[req_distinguished_name]
-commonName=$SERVERNAME
-EOF
 test -f request.cfg || error "could not create request.cfg"
 
 echo "create $SVR_BASE.pem (self signed certificate)"
@@ -125,16 +124,15 @@
 openssl x509 -in $SVR_BASE.pem -addtrust serverAuth -out 
$SVR_BASE"_trust.pem"
 
 # create client request and sign it, piped
-cat >request.cfg < request.cfg
+echo "default_bits=$BITS\n" >> request.cfg
+echo "default_md=$HASH\n" >> request.cfg
+echo "prompt=no\n" >> request.cfg
+echo "distinguished_name=req_distinguished_name\n" >> request.cfg
+echo "\n" >> request.cfg
+echo "[req_distinguished_name]\n" >> request.cfg
+echo "commonName=$CLIENTNAME" >> request.cfg
 
-[req_distinguished_name]
-commonName=$CLIENTNAME
-EOF
 test -f request.cfg || error "could not create request.cfg"
 
 echo "create $CTL_BASE.pem (signed client certificate)"

Whoever wrote this seems to have confused "echo" with "printf".  All the 
trailing "\n" lines cause an openssl error.  In the cluster build I had to 
remove the "\n" and that was sufficient to bootstrap new instances again.

I suspect this error is harmless on bash.  Unfortunately our environment 
cares.

--- head/sys/arm/arm/machdep.c  Wed Feb  3 15:45:13 2016(r295212)
+++ head/sys/arm/arm/machdep.c  Wed Feb  3 16:44:06 2016(r295213)
@@ -1622,7 +1622,7 @@ initarm(struct arm_boot_params *abp)
 
cpu_domains((DOMAIN_CLIENT << (PMAP_DOMAIN_KERNEL * 2)) | 
DOMAIN_CLIENT);
pmap_pa = kernel_l1pt.pv_pa;
-   setttb(kernel_l1pt.pv_pa);
+   cpu_setttb(kernel_l1pt.pv_pa);
cpu_tlb_flushID();
cpu_domains(DOMAIN_CLIENT << (PMAP_DOMAIN_KERNEL * 2));
 
@@ -1675,7 +1675,7 @@ initarm(struct arm_boot_params *abp)
/*
 * We must now clean the cache again
 * Cleaning may be done by reading new data to displace any
 * dirty data in the cache. This will have happened in setttb()
 * but since we are boot strapping the addresses used for the read
 * may have just been remapped and thus the cache could be out
 * of sync. A re-clean after the switch will cure this.
@@ -1867,7 +1867,7 @@ initarm(struct arm_boot_params *abp)
/*
 * We must now clean the cache again
 * Cleaning may be done by reading new data to displace any
 * dirty data in the cache. This will have happened in setttb()
 * but since we are boot strapping the addresses used for the read
 * may have just been remapped and thus the cache could be out
 * of sync. A re-clean after the switch will cure this.

Modified: head/sys/arm/at91/at91_machdep.c
==
--- head/sys/arm/at91/at91_machdep.cWed Feb  3 15:45:13 2016
(r295212)
+++ head/sys/arm/at91/at91_machdep.cWed Feb  3 16:44:06 2016
(r295213)
@@ -566,7 +566,7 @@ initarm(struct arm_boot_params *abp)
 
arm_devmap_bootstrap(l1pagetable, at91_devmap);
cpu_domains((DOMAIN_CLIENT << (PMAP_DOMAIN_KERNEL * 2)) | 
DOMAIN_CLIENT);
-   setttb(kernel_l1pt.pv_pa);
+   cpu_setttb(kernel_l1pt.pv_pa);
cpu_tlb_flushID();
cpu_domains(DOMAIN_CLIENT << (PMAP_DOMAIN_KERNEL * 2));
 
@@ -612,7 +612,7 @@ initarm(struct arm_boot_params *abp)
/*
 * We must now clean the cache again
 * Cleaning may be done by reading new data to displace any
 * dirty data in the cache. This will have happened in setttb()
 * but since we are boot strapping the addresses used for the read
 * may have just been remapped and thus the cache could be out
 * of sync. A re-clean after the switch will cure this.

Modified: head/sys/arm/cavium/cns11xx/econa_machdep.c
==
--- head/sys/arm/cavium/cns11xx/econa_machdep.c Wed Feb  3 15:45:13 2016
(r295212)
+++ head/sys/arm/cavium/cns11xx/econa_machdep.c Wed Feb  3 16:44:06 2016
(r295213)
@@ -275,7 +275,7 @@ initarm(struct arm_boot_params *abp)
 
arm_devmap_bootstrap(l1pagetable, econa_devmap);
cpu_domains((DOMAIN_CLIENT << (PMAP_DOMAIN_KERNEL*2)) | DOMAIN_CLIENT);
-   setttb(kernel_l1pt.pv_pa);
+   cpu_setttb(kernel_l1pt.pv_pa);
cpu_tlb_flushID();
cpu_domains(DOMAIN_CLIENT << (PMAP_DOMAIN_KERNEL*2));
cninit();
@@ -297,7 +297,7 @@ initarm(struct arm_boot_params *abp)
/*
 * We must now clean the cache again
 * Cleaning may be done by reading new data to displace any
 * dirty data in the cache. This will have happened in setttb()
 * but since we are boot strapping the addresses used for the read
 * may have just been remapped and thus the cache could be out
 * of sync. A re-clean after the switch will cure this.

Modified: head/sys/arm/include/cpufunc.h
==
--- head/sys/arm/include/cpufunc.h  Wed Feb  3 15:45:13 2016
(r295212)
+++ head/sys/arm/include/cpufunc.h  Wed Feb  3 16:44:06 2016
(r295213)
@@ -412,9 +412,6 @@ voidxscalec3_context_switch (void);
 
 
@@ -1675,7 +1675,7 @@ initarm(struct arm_boot_params *abp)
 * We must now clean the cache again
 * Cleaning may be done by reading new data to displace any
-* dirty data in the cache. This will have happened in setttb()
+* dirty data in the cache. This will have happened in cpu_setttb()
 * but since we are boot strapping the addresses used for the read
 * may have just been remapped and thus the cache could be out
@@ -1867,7 +1867,7 @@ initarm(struct arm_boot_params *abp)
 * We must now clean the cache again
 * Cleaning may be done by reading new data to displace any
-* dirty data in the cache. This will have happened in setttb()
+* dirty data in the cache. This will have happened in cpu_setttb()
 * but since we are boot strapping the addresses used for the read
 * may have just been remapped and thus the cache could be out
@@ -612,7 +612,7 @@ initarm(struct arm_boot_params *abp)
 * We must now clean the cache again
 * Cleaning may be done by reading new data to displace any
-* dirty data in the cache. This will have happened in setttb()
+* dirty data in the cache. This will have happened in cpu_setttb()
 * but since we are boot strapping the addresses used for the read
 * may have just been remapped and thus the cache could be out
@@ -297,7 +297,7 @@ initarm(struct arm_boot_params *abp)
 * We must now clean the cache again
 * Cleaning may be done by reading new data to displace any
-* dirty data in the cache. This will have happened in setttb()
+* dirty data in the cache. This will have happened in cpu_setttb()
 * but since we are boot strapping the addresses used for the read
 * may have just been remapped and thus the cache could be out

svn commit: r295235 - head/sys/arm/arm

2016-02-03 Thread Michal Meloun
Author: mmel
Date: Thu Feb  4 06:39:20 2016
New Revision: 295235
URL: https://svnweb.freebsd.org/changeset/base/295235

Log:
  ARM: Remove unused symbols from genassym.c.

Modified:
  head/sys/arm/arm/genassym.c

Modified: head/sys/arm/arm/genassym.c
==
-- 
Peter Wemm - pe...@wemm.org; pe...@freebsd.org; pe...@yahoo-inc.com; KI6FJV
UTF-8: for when a ' or ... just won\342\200\231t do\342\200\246

signature.asc
Description: This is a digitally signed message part.


Re: svn commit: r295209 - head/sys/fs/ext2fs

2016-02-03 Thread Conrad Meyer
On Wed, Feb 3, 2016 at 6:31 AM, Pedro F. Giffuni  wrote:
> Author: pfg
> Date: Wed Feb  3 14:31:23 2016
> New Revision: 295209
> URL: https://svnweb.freebsd.org/changeset/base/295209
>
> Log:
>   Revert r294695:
>   ext2fs: passthrough any extra timestamps to the dinode struct.
>
>   While it passed the classic testing, the change appears to have
>   caused some regression and still requires some more precautions.
>
>   PR:   206820

What's the classic testing — xfstests or something more/less thorough?

I was going to ask what the regression was, but then I noticed the PR number.

Thanks,
Conrad
___
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"

Re: svn commit: r292206 - in head/contrib/unbound: . compat daemon dns64 dnstap doc iterator libunbound libunbound/python libunbound/python/doc libunbound/python/doc/modules libunbound/python/examples

2016-02-03 Thread Peter Wemm
On Wednesday, February 03, 2016 10:10:51 AM Peter Wemm wrote:
> On Monday, December 14, 2015 01:01:51 PM Dag-Erling Smørgrav wrote:
> > Author: des
> > Date: Mon Dec 14 13:01:51 2015
> > New Revision: 292206
> > URL: https://svnweb.freebsd.org/changeset/base/292206
> > 
> > Log:
> >   Upgrade to Unbound 1.5.7.
> > 
> > Added:
> >   head/contrib/unbound/.gitignore
> >   
> >  - copied unchanged from r292133, vendor/unbound/dist/.gitignore
> >   
> >   head/contrib/unbound/compat/isblank.c
> >   
> >  - copied unchanged from r292133, vendor/unbound/dist/compat/isblank.c
> > 
> > Modified:
> >   head/contrib/unbound/Makefile.in
> 
> An error was introduced here that breaks some of the support scripts:
> 
> @@ -107,16 +107,15 @@
>  fi
> 
>  # create self-signed cert for server
> -cat >request.cfg < -[req]
> -default_bits=$BITS
> -default_md=$HASH
> -prompt=no
> -distinguished_name=req_distinguished_name
> +echo "[req]\n" > request.cfg
> +echo "default_bits=$BITS\n" >> request.cfg
> +echo "default_md=$HASH\n" >> request.cfg
> +echo "prompt=no\n" >> request.cfg
> +echo "distinguished_name=req_distinguished_name\n" >> request.cfg
> +echo "\n" >> request.cfg
> +echo "[req_distinguished_name]\n" >> request.cfg
> +echo "commonName=$SERVERNAME\n" >> request.cfg
> 
> -[req_distinguished_name]
> -commonName=$SERVERNAME
> -EOF
>  test -f request.cfg || error "could not create request.cfg"
> 
>  echo "create $SVR_BASE.pem (self signed certificate)"
> @@ -125,16 +124,15 @@
>  openssl x509 -in $SVR_BASE.pem -addtrust serverAuth -out
> $SVR_BASE"_trust.pem"
> 
>  # create client request and sign it, piped
> -cat >request.cfg < -[req]
> -default_bits=$BITS
> -default_md=$HASH
> -prompt=no
> -distinguished_name=req_distinguished_name
> +echo "[req]\n" > request.cfg
> +echo "default_bits=$BITS\n" >> request.cfg
> +echo "default_md=$HASH\n" >> request.cfg
> +echo "prompt=no\n" >> request.cfg
> +echo "distinguished_name=req_distinguished_name\n" >> request.cfg
> +echo "\n" >> request.cfg
> +echo "[req_distinguished_name]\n" >> request.cfg
> +echo "commonName=$CLIENTNAME" >> request.cfg
> 
> -[req_distinguished_name]
> -commonName=$CLIENTNAME
> -EOF
>  test -f request.cfg || error "could not create request.cfg"
> 
>  echo "create $CTL_BASE.pem (signed client certificate)"
> 
> Whoever wrote this seems to have confused "echo" with "printf".  All the
> trailing "\n" lines cause an openssl error.  In the cluster build I had to
> remove the "\n" and that was sufficient to bootstrap new instances again.

Filed as https://bugs.freebsd.org/206887
-- 
Peter Wemm - pe...@wemm.org; pe...@freebsd.org; pe...@yahoo-inc.com; KI6FJV
UTF-8: for when a ' or ... just won\342\200\231t do\342\200\246

signature.asc
Description: This is a digitally signed message part.